# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class CsvSnapshot(Base):
	"""The CsvSnapshot class encapsulates a required csvSnapshot node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the CsvSnapshot property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'csvSnapshot'

	def __init__(self, parent):
		super(CsvSnapshot, self).__init__(parent)

	@property
	def CsvDecimalPrecision(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('csvDecimalPrecision')
	@CsvDecimalPrecision.setter
	def CsvDecimalPrecision(self, value):
		self._set_attribute('csvDecimalPrecision', value)

	@property
	def CsvDumpTxPortLabelMap(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('csvDumpTxPortLabelMap')
	@CsvDumpTxPortLabelMap.setter
	def CsvDumpTxPortLabelMap(self, value):
		self._set_attribute('csvDumpTxPortLabelMap', value)

	@property
	def CsvFormatTimestamp(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('csvFormatTimestamp')
	@CsvFormatTimestamp.setter
	def CsvFormatTimestamp(self, value):
		self._set_attribute('csvFormatTimestamp', value)

	@property
	def CsvLocation(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('csvLocation')
	@CsvLocation.setter
	def CsvLocation(self, value):
		self._set_attribute('csvLocation', value)

	@property
	def CsvName(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('csvName')
	@CsvName.setter
	def CsvName(self, value):
		self._set_attribute('csvName', value)

	@property
	def CsvStringQuotes(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('csvStringQuotes')
	@CsvStringQuotes.setter
	def CsvStringQuotes(self, value):
		self._set_attribute('csvStringQuotes', value)

	@property
	def CsvSupportsCSVSorting(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('csvSupportsCSVSorting')
	@CsvSupportsCSVSorting.setter
	def CsvSupportsCSVSorting(self, value):
		self._set_attribute('csvSupportsCSVSorting', value)

	@property
	def NextGenRefreshBeforeSnapshot(self):
		"""DEPRECATED nextGenRefreshBeforeSnapshot is deprecated and has no effect starting from IxNetwork 8.10.

		Returns:
			bool
		"""
		return self._get_attribute('nextGenRefreshBeforeSnapshot')
	@NextGenRefreshBeforeSnapshot.setter
	def NextGenRefreshBeforeSnapshot(self, value):
		self._set_attribute('nextGenRefreshBeforeSnapshot', value)

	@property
	def OpenViewer(self):
		"""DEPRECATED 

		Returns:
			bool
		"""
		return self._get_attribute('openViewer')
	@OpenViewer.setter
	def OpenViewer(self, value):
		self._set_attribute('openViewer', value)

	@property
	def SnapshotSettingsName(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('snapshotSettingsName')

	@property
	def SnapshotViewContents(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(allPages|currentPage)
		"""
		return self._get_attribute('snapshotViewContents')
	@SnapshotViewContents.setter
	def SnapshotViewContents(self, value):
		self._set_attribute('snapshotViewContents', value)

	@property
	def SnapshotViewCsvGenerationMode(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(appendCSVFile|newCSVFile|overwriteCSVFile)
		"""
		return self._get_attribute('snapshotViewCsvGenerationMode')
	@SnapshotViewCsvGenerationMode.setter
	def SnapshotViewCsvGenerationMode(self, value):
		self._set_attribute('snapshotViewCsvGenerationMode', value)

	@property
	def Views(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=view])
		"""
		return self._get_attribute('views')
	@Views.setter
	def Views(self, value):
		self._set_attribute('views', value)

	def update(self, CsvDecimalPrecision=None, CsvDumpTxPortLabelMap=None, CsvFormatTimestamp=None, CsvLocation=None, CsvName=None, CsvStringQuotes=None, CsvSupportsCSVSorting=None, NextGenRefreshBeforeSnapshot=None, OpenViewer=None, SnapshotViewContents=None, SnapshotViewCsvGenerationMode=None, Views=None):
		"""Updates a child instance of csvSnapshot on the server.

		Args:
			CsvDecimalPrecision (number): NOT DEFINED
			CsvDumpTxPortLabelMap (bool): NOT DEFINED
			CsvFormatTimestamp (bool): NOT DEFINED
			CsvLocation (str): NOT DEFINED
			CsvName (str): 
			CsvStringQuotes (bool): NOT DEFINED
			CsvSupportsCSVSorting (bool): NOT DEFINED
			NextGenRefreshBeforeSnapshot (bool): nextGenRefreshBeforeSnapshot is deprecated and has no effect starting from IxNetwork 8.10.
			OpenViewer (bool): 
			SnapshotViewContents (str(allPages|currentPage)): NOT DEFINED
			SnapshotViewCsvGenerationMode (str(appendCSVFile|newCSVFile|overwriteCSVFile)): NOT DEFINED
			Views (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=view])): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def ResetToDefaults(self):
		"""Executes the resetToDefaults operation on the server.

		NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('resetToDefaults', payload=payload, response_object=None)

	def TakeCsvSnapshot(self):
		"""Executes the takeCsvSnapshot operation on the server.

		Takes CSV Snapshot. The views and other settings must be set before the call using the /statistics/csvSnapshot attributes.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('takeCsvSnapshot', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SwitchFlowLearnedInfo(Base):
	"""The SwitchFlowLearnedInfo class encapsulates a system managed switchFlowLearnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SwitchFlowLearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'switchFlowLearnedInfo'

	def __init__(self, parent):
		super(SwitchFlowLearnedInfo, self).__init__(parent)

	@property
	def SwitchActionLearnedInfo(self):
		"""An instance of the SwitchActionLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchactionlearnedinfo.SwitchActionLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchactionlearnedinfo import SwitchActionLearnedInfo
		return SwitchActionLearnedInfo(self)

	@property
	def SwitchFlowInstructionLearnedInfo(self):
		"""An instance of the SwitchFlowInstructionLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflowinstructionlearnedinfo.SwitchFlowInstructionLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchflowinstructionlearnedinfo import SwitchFlowInstructionLearnedInfo
		return SwitchFlowInstructionLearnedInfo(self)

	@property
	def ActiveNanoSeconds(self):
		"""This describes the duration (in ns) for which the flow entry is active.

		Returns:
			number
		"""
		return self._get_attribute('activeNanoSeconds')

	@property
	def ActiveSeconds(self):
		"""This describes the duration (in sec) for which the flow entry is active.

		Returns:
			number
		"""
		return self._get_attribute('activeSeconds')

	@property
	def ArpDstHwAddress(self):
		"""This describes the target hardware address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpDstHwAddress')

	@property
	def ArpDstHwAddressMask(self):
		"""This describes the mask value of the target hardware address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpDstHwAddressMask')

	@property
	def ArpDstIpv4Address(self):
		"""This describes the target IPv4 address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpDstIpv4Address')

	@property
	def ArpDstIpv4AddressMask(self):
		"""This describes the mask value of the target IPv4 address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpDstIpv4AddressMask')

	@property
	def ArpOpcode(self):
		"""This describes the ARP opcode.

		Returns:
			str
		"""
		return self._get_attribute('arpOpcode')

	@property
	def ArpSrcHwAddress(self):
		"""This describes the source hardware address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpSrcHwAddress')

	@property
	def ArpSrcHwAddressMask(self):
		"""This describes the mask value of the source hardware address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpSrcHwAddressMask')

	@property
	def ArpSrcIpv4Address(self):
		"""This describes the source IPv4 address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpSrcIpv4Address')

	@property
	def ArpSrcIpv4AddressMask(self):
		"""This describes the mask value of the source IPv4 address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpSrcIpv4AddressMask')

	@property
	def BytesCount(self):
		"""This describes the number of bytes in flow.

		Returns:
			str
		"""
		return self._get_attribute('bytesCount')

	@property
	def Cookie(self):
		"""This describes the opaque controller-issued identifier.

		Returns:
			str
		"""
		return self._get_attribute('cookie')

	@property
	def CookieMask(self):
		"""This describes the mask used to restrict the cookie bits.

		Returns:
			str
		"""
		return self._get_attribute('cookieMask')

	@property
	def DataPathId(self):
		"""This describes the datapath ID of the switch.

		Returns:
			str
		"""
		return self._get_attribute('dataPathId')

	@property
	def DataPathIdAsHex(self):
		"""This describes the datapath ID, in hexadecimal format, of the switch.

		Returns:
			str
		"""
		return self._get_attribute('dataPathIdAsHex')

	@property
	def EthernetDestination(self):
		"""This describes the ethernet destination address of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestination')

	@property
	def EthernetDestinationMask(self):
		"""This describes the Ethernet destination mask value.

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestinationMask')

	@property
	def EthernetSource(self):
		"""This describes the ethernet source address of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ethernetSource')

	@property
	def EthernetSourceMask(self):
		"""This describes the Ethernet Source mask value.

		Returns:
			str
		"""
		return self._get_attribute('ethernetSourceMask')

	@property
	def EthernetType(self):
		"""This describes the Ethernet type of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ethernetType')

	@property
	def ExperimenterData(self):
		"""This describes the data of the Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('experimenterData')

	@property
	def ExperimenterDataLength(self):
		"""This describes the data length of the Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('experimenterDataLength')

	@property
	def ExperimenterField(self):
		"""This describes the field type for experimenter match.

		Returns:
			number
		"""
		return self._get_attribute('experimenterField')

	@property
	def ExperimenterHashMask(self):
		"""This describes the experimenter hash mask value.

		Returns:
			bool
		"""
		return self._get_attribute('experimenterHashMask')

	@property
	def ExperimenterId(self):
		"""This describes the unique identifier for the Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('experimenterId')

	@property
	def Flags(self):
		"""This describes the flags used for this configuration.

		Returns:
			number
		"""
		return self._get_attribute('flags')

	@property
	def HardTimeout(self):
		"""This describes the duration (in sec) before expiration.

		Returns:
			number
		"""
		return self._get_attribute('hardTimeout')

	@property
	def Icmpv4Code(self):
		"""This describes the ICMP code.

		Returns:
			str
		"""
		return self._get_attribute('icmpv4Code')

	@property
	def Icmpv4Type(self):
		"""This describes the ICMP type.

		Returns:
			str
		"""
		return self._get_attribute('icmpv4Type')

	@property
	def Icmpv6Code(self):
		"""This describes the ICMPv6 code.

		Returns:
			str
		"""
		return self._get_attribute('icmpv6Code')

	@property
	def Icmpv6Type(self):
		"""This describes the ICMPv6 type.

		Returns:
			str
		"""
		return self._get_attribute('icmpv6Type')

	@property
	def IdleTimeout(self):
		"""This describes the duration (in sec) for which the switch is idle before expiration.

		Returns:
			number
		"""
		return self._get_attribute('idleTimeout')

	@property
	def InPort(self):
		"""This describes the input port of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('inPort')

	@property
	def IpDscp(self):
		"""This describes the IP ToS of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ipDscp')

	@property
	def IpEcn(self):
		"""This describes the ECN bits of the IP header.

		Returns:
			str
		"""
		return self._get_attribute('ipEcn')

	@property
	def IpProtocol(self):
		"""This describes the IP Protocol type of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ipProtocol')

	@property
	def Ipv4Destination(self):
		"""This describes the IPv4 destination of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Destination')

	@property
	def Ipv4Source(self):
		"""This describes the IPv4 source address of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Source')

	@property
	def Ipv6Destination(self):
		"""This describes the IPv6 destination address.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Destination')

	@property
	def Ipv6DestinationMask(self):
		"""This describes the mask value of IPv6 destination address.

		Returns:
			str
		"""
		return self._get_attribute('ipv6DestinationMask')

	@property
	def Ipv6ExtHeader(self):
		"""The IPv6 Extension Header pseudo-field.

		Returns:
			number
		"""
		return self._get_attribute('ipv6ExtHeader')

	@property
	def Ipv6ExtHeaderMask(self):
		"""This describes the mask value of the IPv6 Extension Header.

		Returns:
			number
		"""
		return self._get_attribute('ipv6ExtHeaderMask')

	@property
	def Ipv6FlowLabel(self):
		"""This describes the IPv6 Flow label.

		Returns:
			str
		"""
		return self._get_attribute('ipv6FlowLabel')

	@property
	def Ipv6FlowLabelMask(self):
		"""This describes the mask value of IPv6 Flow label.

		Returns:
			str
		"""
		return self._get_attribute('ipv6FlowLabelMask')

	@property
	def Ipv6NdDll(self):
		"""The target link-layer address option in an IPv6 Neighbor Discovery message.

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdDll')

	@property
	def Ipv6NdSll(self):
		"""This describes the source link-layer address option in an IPv6 Neighbor Discovery message.

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdSll')

	@property
	def Ipv6NdTarget(self):
		"""This describes the target address in an IPv6 Neighbor Discovery message.

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdTarget')

	@property
	def Ipv6Source(self):
		"""This describes the IPv6 source address.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Source')

	@property
	def Ipv6SourceMask(self):
		"""This describes the mask value of IPv6 source address.

		Returns:
			str
		"""
		return self._get_attribute('ipv6SourceMask')

	@property
	def LocalIp(self):
		"""This describes the local IP address of the switch.

		Returns:
			str
		"""
		return self._get_attribute('localIp')

	@property
	def Metadata(self):
		"""This describes the table metadata value used to pass information between tables.

		Returns:
			str
		"""
		return self._get_attribute('metadata')

	@property
	def MetadataMask(self):
		"""This describes the metadata bitmask value.

		Returns:
			str
		"""
		return self._get_attribute('metadataMask')

	@property
	def MplsBos(self):
		"""This describes the BoS bit in the first MPLS shim header.

		Returns:
			str
		"""
		return self._get_attribute('mplsBos')

	@property
	def MplsLabel(self):
		"""This describes the LABEL in the first MPLS shim header.

		Returns:
			str
		"""
		return self._get_attribute('mplsLabel')

	@property
	def MplsTc(self):
		"""This describes the TC in the first MPLS shim header.

		Returns:
			str
		"""
		return self._get_attribute('mplsTc')

	@property
	def NegotiatedVersion(self):
		"""This describes the OpenFlow version supported by this configuration.

		Returns:
			str
		"""
		return self._get_attribute('negotiatedVersion')

	@property
	def NumberOfInstructions(self):
		"""This describes the number of instructions for this Flow range. The default value is 0. The minimum value is 0 and the maximum value is 10.

		Returns:
			str
		"""
		return self._get_attribute('numberOfInstructions')

	@property
	def NumberofActions(self):
		"""This describes the number of actions associated with the flow entry.

		Returns:
			str
		"""
		return self._get_attribute('numberofActions')

	@property
	def OutGroup(self):
		"""This describes the out group value. It requires matching entries to include this as an output group.

		Returns:
			number
		"""
		return self._get_attribute('outGroup')

	@property
	def OutPort(self):
		"""This describes the out port value. It requires matching entries to include this as an output port.

		Returns:
			number
		"""
		return self._get_attribute('outPort')

	@property
	def PacketsCount(self):
		"""This describes the number of packets in flow.

		Returns:
			str
		"""
		return self._get_attribute('packetsCount')

	@property
	def PbbIsid(self):
		"""This describes the I-SID in the first PBB service instance tag.

		Returns:
			str
		"""
		return self._get_attribute('pbbIsid')

	@property
	def PbbIsidMask(self):
		"""This describes the mask value of PBB I-SID.

		Returns:
			str
		"""
		return self._get_attribute('pbbIsidMask')

	@property
	def PhysicalInPort(self):
		"""This describes the physical In port value for this flow range. It is the underlying physical port when packet is received on a logical port.

		Returns:
			str
		"""
		return self._get_attribute('physicalInPort')

	@property
	def Priority(self):
		"""This describes the Priority of the flow entry.

		Returns:
			number
		"""
		return self._get_attribute('priority')

	@property
	def RemoteIp(self):
		"""This describes the IP address of the remote end of the OF Channel.

		Returns:
			str
		"""
		return self._get_attribute('remoteIp')

	@property
	def SctpDestination(self):
		"""This describes the SCTP target port.

		Returns:
			str
		"""
		return self._get_attribute('sctpDestination')

	@property
	def SctpSource(self):
		"""This describes the SCTP source port.

		Returns:
			str
		"""
		return self._get_attribute('sctpSource')

	@property
	def TableId(self):
		"""This describes the ID of the table in which the entry is stored.

		Returns:
			str
		"""
		return self._get_attribute('tableId')

	@property
	def TcpDestination(self):
		"""This describes the TCP destination port.

		Returns:
			str
		"""
		return self._get_attribute('tcpDestination')

	@property
	def TcpSource(self):
		"""This describes the TCP source port.

		Returns:
			str
		"""
		return self._get_attribute('tcpSource')

	@property
	def TransportDestination(self):
		"""This describes the transport destination port of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('transportDestination')

	@property
	def TransportSource(self):
		"""This describes the transport source port of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('transportSource')

	@property
	def TunnelId(self):
		"""This describes the unique identifier used for the Tunnel.

		Returns:
			str
		"""
		return self._get_attribute('tunnelId')

	@property
	def TunnelIdMask(self):
		"""This describes the Tunnel ID mask value.

		Returns:
			str
		"""
		return self._get_attribute('tunnelIdMask')

	@property
	def UdpDestination(self):
		"""This describes the UDP destination port.

		Returns:
			str
		"""
		return self._get_attribute('udpDestination')

	@property
	def UdpSource(self):
		"""This describes the UDP source port.

		Returns:
			str
		"""
		return self._get_attribute('udpSource')

	@property
	def VlanId(self):
		"""This describes the VLAN ID of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('vlanId')

	@property
	def VlanMask(self):
		"""This describes the VLAN mask value.

		Returns:
			number
		"""
		return self._get_attribute('vlanMask')

	@property
	def VlanPriority(self):
		"""This describes the VLAN Priority of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('vlanPriority')

	def find(self, ActiveNanoSeconds=None, ActiveSeconds=None, ArpDstHwAddress=None, ArpDstHwAddressMask=None, ArpDstIpv4Address=None, ArpDstIpv4AddressMask=None, ArpOpcode=None, ArpSrcHwAddress=None, ArpSrcHwAddressMask=None, ArpSrcIpv4Address=None, ArpSrcIpv4AddressMask=None, BytesCount=None, Cookie=None, CookieMask=None, DataPathId=None, DataPathIdAsHex=None, EthernetDestination=None, EthernetDestinationMask=None, EthernetSource=None, EthernetSourceMask=None, EthernetType=None, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterField=None, ExperimenterHashMask=None, ExperimenterId=None, Flags=None, HardTimeout=None, Icmpv4Code=None, Icmpv4Type=None, Icmpv6Code=None, Icmpv6Type=None, IdleTimeout=None, InPort=None, IpDscp=None, IpEcn=None, IpProtocol=None, Ipv4Destination=None, Ipv4Source=None, Ipv6Destination=None, Ipv6DestinationMask=None, Ipv6ExtHeader=None, Ipv6ExtHeaderMask=None, Ipv6FlowLabel=None, Ipv6FlowLabelMask=None, Ipv6NdDll=None, Ipv6NdSll=None, Ipv6NdTarget=None, Ipv6Source=None, Ipv6SourceMask=None, LocalIp=None, Metadata=None, MetadataMask=None, MplsBos=None, MplsLabel=None, MplsTc=None, NegotiatedVersion=None, NumberOfInstructions=None, NumberofActions=None, OutGroup=None, OutPort=None, PacketsCount=None, PbbIsid=None, PbbIsidMask=None, PhysicalInPort=None, Priority=None, RemoteIp=None, SctpDestination=None, SctpSource=None, TableId=None, TcpDestination=None, TcpSource=None, TransportDestination=None, TransportSource=None, TunnelId=None, TunnelIdMask=None, UdpDestination=None, UdpSource=None, VlanId=None, VlanMask=None, VlanPriority=None):
		"""Finds and retrieves switchFlowLearnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve switchFlowLearnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all switchFlowLearnedInfo data from the server.

		Args:
			ActiveNanoSeconds (number): This describes the duration (in ns) for which the flow entry is active.
			ActiveSeconds (number): This describes the duration (in sec) for which the flow entry is active.
			ArpDstHwAddress (str): This describes the target hardware address in the ARP payload.
			ArpDstHwAddressMask (str): This describes the mask value of the target hardware address in the ARP payload.
			ArpDstIpv4Address (str): This describes the target IPv4 address in the ARP payload.
			ArpDstIpv4AddressMask (str): This describes the mask value of the target IPv4 address in the ARP payload.
			ArpOpcode (str): This describes the ARP opcode.
			ArpSrcHwAddress (str): This describes the source hardware address in the ARP payload.
			ArpSrcHwAddressMask (str): This describes the mask value of the source hardware address in the ARP payload.
			ArpSrcIpv4Address (str): This describes the source IPv4 address in the ARP payload.
			ArpSrcIpv4AddressMask (str): This describes the mask value of the source IPv4 address in the ARP payload.
			BytesCount (str): This describes the number of bytes in flow.
			Cookie (str): This describes the opaque controller-issued identifier.
			CookieMask (str): This describes the mask used to restrict the cookie bits.
			DataPathId (str): This describes the datapath ID of the switch.
			DataPathIdAsHex (str): This describes the datapath ID, in hexadecimal format, of the switch.
			EthernetDestination (str): This describes the ethernet destination address of the flow match.
			EthernetDestinationMask (str): This describes the Ethernet destination mask value.
			EthernetSource (str): This describes the ethernet source address of the flow match.
			EthernetSourceMask (str): This describes the Ethernet Source mask value.
			EthernetType (str): This describes the Ethernet type of the flow match.
			ExperimenterData (str): This describes the data of the Experimenter.
			ExperimenterDataLength (number): This describes the data length of the Experimenter.
			ExperimenterField (number): This describes the field type for experimenter match.
			ExperimenterHashMask (bool): This describes the experimenter hash mask value.
			ExperimenterId (str): This describes the unique identifier for the Experimenter.
			Flags (number): This describes the flags used for this configuration.
			HardTimeout (number): This describes the duration (in sec) before expiration.
			Icmpv4Code (str): This describes the ICMP code.
			Icmpv4Type (str): This describes the ICMP type.
			Icmpv6Code (str): This describes the ICMPv6 code.
			Icmpv6Type (str): This describes the ICMPv6 type.
			IdleTimeout (number): This describes the duration (in sec) for which the switch is idle before expiration.
			InPort (str): This describes the input port of the flow match.
			IpDscp (str): This describes the IP ToS of the flow match.
			IpEcn (str): This describes the ECN bits of the IP header.
			IpProtocol (str): This describes the IP Protocol type of the flow match.
			Ipv4Destination (str): This describes the IPv4 destination of the flow match.
			Ipv4Source (str): This describes the IPv4 source address of the flow match.
			Ipv6Destination (str): This describes the IPv6 destination address.
			Ipv6DestinationMask (str): This describes the mask value of IPv6 destination address.
			Ipv6ExtHeader (number): The IPv6 Extension Header pseudo-field.
			Ipv6ExtHeaderMask (number): This describes the mask value of the IPv6 Extension Header.
			Ipv6FlowLabel (str): This describes the IPv6 Flow label.
			Ipv6FlowLabelMask (str): This describes the mask value of IPv6 Flow label.
			Ipv6NdDll (str): The target link-layer address option in an IPv6 Neighbor Discovery message.
			Ipv6NdSll (str): This describes the source link-layer address option in an IPv6 Neighbor Discovery message.
			Ipv6NdTarget (str): This describes the target address in an IPv6 Neighbor Discovery message.
			Ipv6Source (str): This describes the IPv6 source address.
			Ipv6SourceMask (str): This describes the mask value of IPv6 source address.
			LocalIp (str): This describes the local IP address of the switch.
			Metadata (str): This describes the table metadata value used to pass information between tables.
			MetadataMask (str): This describes the metadata bitmask value.
			MplsBos (str): This describes the BoS bit in the first MPLS shim header.
			MplsLabel (str): This describes the LABEL in the first MPLS shim header.
			MplsTc (str): This describes the TC in the first MPLS shim header.
			NegotiatedVersion (str): This describes the OpenFlow version supported by this configuration.
			NumberOfInstructions (str): This describes the number of instructions for this Flow range. The default value is 0. The minimum value is 0 and the maximum value is 10.
			NumberofActions (str): This describes the number of actions associated with the flow entry.
			OutGroup (number): This describes the out group value. It requires matching entries to include this as an output group.
			OutPort (number): This describes the out port value. It requires matching entries to include this as an output port.
			PacketsCount (str): This describes the number of packets in flow.
			PbbIsid (str): This describes the I-SID in the first PBB service instance tag.
			PbbIsidMask (str): This describes the mask value of PBB I-SID.
			PhysicalInPort (str): This describes the physical In port value for this flow range. It is the underlying physical port when packet is received on a logical port.
			Priority (number): This describes the Priority of the flow entry.
			RemoteIp (str): This describes the IP address of the remote end of the OF Channel.
			SctpDestination (str): This describes the SCTP target port.
			SctpSource (str): This describes the SCTP source port.
			TableId (str): This describes the ID of the table in which the entry is stored.
			TcpDestination (str): This describes the TCP destination port.
			TcpSource (str): This describes the TCP source port.
			TransportDestination (str): This describes the transport destination port of the flow match.
			TransportSource (str): This describes the transport source port of the flow match.
			TunnelId (str): This describes the unique identifier used for the Tunnel.
			TunnelIdMask (str): This describes the Tunnel ID mask value.
			UdpDestination (str): This describes the UDP destination port.
			UdpSource (str): This describes the UDP source port.
			VlanId (str): This describes the VLAN ID of the flow match.
			VlanMask (number): This describes the VLAN mask value.
			VlanPriority (str): This describes the VLAN Priority of the flow match.

		Returns:
			self: This instance with matching switchFlowLearnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of switchFlowLearnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the switchFlowLearnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Modifier(Base):
	"""The Modifier class encapsulates a user managed modifier node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Modifier property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'modifier'

	def __init__(self, parent):
		super(Modifier, self).__init__(parent)

	@property
	def ClusterSize(self):
		"""Number of packets to modify on each occurrence. Default: 1.

		Returns:
			number
		"""
		return self._get_attribute('clusterSize')
	@ClusterSize.setter
	def ClusterSize(self, value):
		self._set_attribute('clusterSize', value)

	@property
	def Enabled(self):
		"""If true, modify incoming packets.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def L3MatchEtherType(self):
		"""EtherType value to match.

		Returns:
			str
		"""
		return self._get_attribute('l3MatchEtherType')
	@L3MatchEtherType.setter
	def L3MatchEtherType(self, value):
		self._set_attribute('l3MatchEtherType', value)

	@property
	def L3MatchMode(self):
		"""For an L3 offset, specify whether to modify only packets with a specific EtherType or bottom MPLS label.

		Returns:
			str(matchAny|matchBottomMplsLabel|matchEtherType)
		"""
		return self._get_attribute('l3MatchMode')
	@L3MatchMode.setter
	def L3MatchMode(self, value):
		self._set_attribute('l3MatchMode', value)

	@property
	def L3MatchMplsLabel(self):
		"""MPLS label to match.

		Returns:
			number
		"""
		return self._get_attribute('l3MatchMplsLabel')
	@L3MatchMplsLabel.setter
	def L3MatchMplsLabel(self, value):
		self._set_attribute('l3MatchMplsLabel', value)

	@property
	def L4MatchEncapsulation(self):
		"""For an L4 offset, specify whether to modify IPv4 packets, IPv6 packets, or both.

		Returns:
			str(matchIpv4|matchIpv4OrIpv6|matchIpv6)
		"""
		return self._get_attribute('l4MatchEncapsulation')
	@L4MatchEncapsulation.setter
	def L4MatchEncapsulation(self, value):
		self._set_attribute('l4MatchEncapsulation', value)

	@property
	def L4MatchMode(self):
		"""For an L4 offset, specify whether to modify only packets with a specific protocol number.

		Returns:
			str(matchAny|matchProtocolNumber)
		"""
		return self._get_attribute('l4MatchMode')
	@L4MatchMode.setter
	def L4MatchMode(self, value):
		self._set_attribute('l4MatchMode', value)

	@property
	def L4MatchProtocolNumber(self):
		"""Protocol number to match.

		Returns:
			number
		"""
		return self._get_attribute('l4MatchProtocolNumber')
	@L4MatchProtocolNumber.setter
	def L4MatchProtocolNumber(self, value):
		self._set_attribute('l4MatchProtocolNumber', value)

	@property
	def L5MatchEncapsulation(self):
		"""For an L5 offset, specify whether to modify TCP packets only or UDP packets only.

		Returns:
			str(matchTcp|matchUdp)
		"""
		return self._get_attribute('l5MatchEncapsulation')
	@L5MatchEncapsulation.setter
	def L5MatchEncapsulation(self, value):
		self._set_attribute('l5MatchEncapsulation', value)

	@property
	def L5MatchMode(self):
		"""For an L5 offset, specify whether to modify only packets with a specific source or destination port number.

		Returns:
			str(matchAny|matchDestinationPort|matchSourceOrDestinationPort|matchSourcePort)
		"""
		return self._get_attribute('l5MatchMode')
	@L5MatchMode.setter
	def L5MatchMode(self, value):
		self._set_attribute('l5MatchMode', value)

	@property
	def L5MatchPortNumber(self):
		"""Port number to match.

		Returns:
			number
		"""
		return self._get_attribute('l5MatchPortNumber')
	@L5MatchPortNumber.setter
	def L5MatchPortNumber(self, value):
		self._set_attribute('l5MatchPortNumber', value)

	@property
	def Mask(self):
		"""Mask identifying the bits of the field to be modified, as a hex string with prefix 0x (e.g. 0xFF FF). The bits of the mask must be contiguous.

		Returns:
			str
		"""
		return self._get_attribute('mask')
	@Mask.setter
	def Mask(self, value):
		self._set_attribute('mask', value)

	@property
	def MatchValue(self):
		"""Value to be matched. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).

		Returns:
			str
		"""
		return self._get_attribute('matchValue')
	@MatchValue.setter
	def MatchValue(self, value):
		self._set_attribute('matchValue', value)

	@property
	def MatchValueEnabled(self):
		"""Only modify packets if the existing field value matches a specified value.

		Returns:
			bool
		"""
		return self._get_attribute('matchValueEnabled')
	@MatchValueEnabled.setter
	def MatchValueEnabled(self, value):
		self._set_attribute('matchValueEnabled', value)

	@property
	def Name(self):
		"""Name of the modifier.

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def Offset(self):
		"""The position of the field to be modified, as an offset in bytes.

		Returns:
			number
		"""
		return self._get_attribute('offset')
	@Offset.setter
	def Offset(self, value):
		self._set_attribute('offset', value)

	@property
	def OffsetStart(self):
		"""Define the position of the field to be modified, as an offset from a specified position. Default is from the start of the L2 header.

		Returns:
			str(l2Offset|l3Offset|l4Offset|l5Offset)
		"""
		return self._get_attribute('offsetStart')
	@OffsetStart.setter
	def OffsetStart(self, value):
		self._set_attribute('offsetStart', value)

	@property
	def PercentRate(self):
		"""How often to modify matching packets. Default: 100%.

		Returns:
			number
		"""
		return self._get_attribute('percentRate')
	@PercentRate.setter
	def PercentRate(self, value):
		self._set_attribute('percentRate', value)

	@property
	def ReplaceFixedValue(self):
		"""Fixed replacement value. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).

		Returns:
			str
		"""
		return self._get_attribute('replaceFixedValue')
	@ReplaceFixedValue.setter
	def ReplaceFixedValue(self, value):
		self._set_attribute('replaceFixedValue', value)

	@property
	def ReplaceMode(self):
		"""Replace field with a fixed value or a range of values.

		Returns:
			str(fixedValue|range)
		"""
		return self._get_attribute('replaceMode')
	@ReplaceMode.setter
	def ReplaceMode(self, value):
		self._set_attribute('replaceMode', value)

	@property
	def ReplaceRangeCount(self):
		"""Number of values in range. Can be any value up to ceiling(2^width / step), where width is the width of the field mask.

		Returns:
			str
		"""
		return self._get_attribute('replaceRangeCount')
	@ReplaceRangeCount.setter
	def ReplaceRangeCount(self, value):
		self._set_attribute('replaceRangeCount', value)

	@property
	def ReplaceRangeDecrement(self):
		"""Decrement instead of incrementing. Default: false.

		Returns:
			bool
		"""
		return self._get_attribute('replaceRangeDecrement')
	@ReplaceRangeDecrement.setter
	def ReplaceRangeDecrement(self, value):
		self._set_attribute('replaceRangeDecrement', value)

	@property
	def ReplaceRangeFirst(self):
		"""Start of range.

		Returns:
			str
		"""
		return self._get_attribute('replaceRangeFirst')
	@ReplaceRangeFirst.setter
	def ReplaceRangeFirst(self, value):
		self._set_attribute('replaceRangeFirst', value)

	@property
	def ReplaceRangeStep(self):
		"""Step to be added or subtracted for each modified packet.

		Returns:
			str
		"""
		return self._get_attribute('replaceRangeStep')
	@ReplaceRangeStep.setter
	def ReplaceRangeStep(self, value):
		self._set_attribute('replaceRangeStep', value)

	def update(self, ClusterSize=None, Enabled=None, L3MatchEtherType=None, L3MatchMode=None, L3MatchMplsLabel=None, L4MatchEncapsulation=None, L4MatchMode=None, L4MatchProtocolNumber=None, L5MatchEncapsulation=None, L5MatchMode=None, L5MatchPortNumber=None, Mask=None, MatchValue=None, MatchValueEnabled=None, Name=None, Offset=None, OffsetStart=None, PercentRate=None, ReplaceFixedValue=None, ReplaceMode=None, ReplaceRangeCount=None, ReplaceRangeDecrement=None, ReplaceRangeFirst=None, ReplaceRangeStep=None):
		"""Updates a child instance of modifier on the server.

		Args:
			ClusterSize (number): Number of packets to modify on each occurrence. Default: 1.
			Enabled (bool): If true, modify incoming packets.
			L3MatchEtherType (str): EtherType value to match.
			L3MatchMode (str(matchAny|matchBottomMplsLabel|matchEtherType)): For an L3 offset, specify whether to modify only packets with a specific EtherType or bottom MPLS label.
			L3MatchMplsLabel (number): MPLS label to match.
			L4MatchEncapsulation (str(matchIpv4|matchIpv4OrIpv6|matchIpv6)): For an L4 offset, specify whether to modify IPv4 packets, IPv6 packets, or both.
			L4MatchMode (str(matchAny|matchProtocolNumber)): For an L4 offset, specify whether to modify only packets with a specific protocol number.
			L4MatchProtocolNumber (number): Protocol number to match.
			L5MatchEncapsulation (str(matchTcp|matchUdp)): For an L5 offset, specify whether to modify TCP packets only or UDP packets only.
			L5MatchMode (str(matchAny|matchDestinationPort|matchSourceOrDestinationPort|matchSourcePort)): For an L5 offset, specify whether to modify only packets with a specific source or destination port number.
			L5MatchPortNumber (number): Port number to match.
			Mask (str): Mask identifying the bits of the field to be modified, as a hex string with prefix 0x (e.g. 0xFF FF). The bits of the mask must be contiguous.
			MatchValue (str): Value to be matched. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).
			MatchValueEnabled (bool): Only modify packets if the existing field value matches a specified value.
			Name (str): Name of the modifier.
			Offset (number): The position of the field to be modified, as an offset in bytes.
			OffsetStart (str(l2Offset|l3Offset|l4Offset|l5Offset)): Define the position of the field to be modified, as an offset from a specified position. Default is from the start of the L2 header.
			PercentRate (number): How often to modify matching packets. Default: 100%.
			ReplaceFixedValue (str): Fixed replacement value. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).
			ReplaceMode (str(fixedValue|range)): Replace field with a fixed value or a range of values.
			ReplaceRangeCount (str): Number of values in range. Can be any value up to ceiling(2^width / step), where width is the width of the field mask.
			ReplaceRangeDecrement (bool): Decrement instead of incrementing. Default: false.
			ReplaceRangeFirst (str): Start of range.
			ReplaceRangeStep (str): Step to be added or subtracted for each modified packet.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ClusterSize=None, Enabled=None, L3MatchEtherType=None, L3MatchMode=None, L3MatchMplsLabel=None, L4MatchEncapsulation=None, L4MatchMode=None, L4MatchProtocolNumber=None, L5MatchEncapsulation=None, L5MatchMode=None, L5MatchPortNumber=None, Mask=None, MatchValue=None, MatchValueEnabled=None, Name=None, Offset=None, OffsetStart=None, PercentRate=None, ReplaceFixedValue=None, ReplaceMode=None, ReplaceRangeCount=None, ReplaceRangeDecrement=None, ReplaceRangeFirst=None, ReplaceRangeStep=None):
		"""Adds a new modifier node on the server and retrieves it in this instance.

		Args:
			ClusterSize (number): Number of packets to modify on each occurrence. Default: 1.
			Enabled (bool): If true, modify incoming packets.
			L3MatchEtherType (str): EtherType value to match.
			L3MatchMode (str(matchAny|matchBottomMplsLabel|matchEtherType)): For an L3 offset, specify whether to modify only packets with a specific EtherType or bottom MPLS label.
			L3MatchMplsLabel (number): MPLS label to match.
			L4MatchEncapsulation (str(matchIpv4|matchIpv4OrIpv6|matchIpv6)): For an L4 offset, specify whether to modify IPv4 packets, IPv6 packets, or both.
			L4MatchMode (str(matchAny|matchProtocolNumber)): For an L4 offset, specify whether to modify only packets with a specific protocol number.
			L4MatchProtocolNumber (number): Protocol number to match.
			L5MatchEncapsulation (str(matchTcp|matchUdp)): For an L5 offset, specify whether to modify TCP packets only or UDP packets only.
			L5MatchMode (str(matchAny|matchDestinationPort|matchSourceOrDestinationPort|matchSourcePort)): For an L5 offset, specify whether to modify only packets with a specific source or destination port number.
			L5MatchPortNumber (number): Port number to match.
			Mask (str): Mask identifying the bits of the field to be modified, as a hex string with prefix 0x (e.g. 0xFF FF). The bits of the mask must be contiguous.
			MatchValue (str): Value to be matched. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).
			MatchValueEnabled (bool): Only modify packets if the existing field value matches a specified value.
			Name (str): Name of the modifier.
			Offset (number): The position of the field to be modified, as an offset in bytes.
			OffsetStart (str(l2Offset|l3Offset|l4Offset|l5Offset)): Define the position of the field to be modified, as an offset from a specified position. Default is from the start of the L2 header.
			PercentRate (number): How often to modify matching packets. Default: 100%.
			ReplaceFixedValue (str): Fixed replacement value. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).
			ReplaceMode (str(fixedValue|range)): Replace field with a fixed value or a range of values.
			ReplaceRangeCount (str): Number of values in range. Can be any value up to ceiling(2^width / step), where width is the width of the field mask.
			ReplaceRangeDecrement (bool): Decrement instead of incrementing. Default: false.
			ReplaceRangeFirst (str): Start of range.
			ReplaceRangeStep (str): Step to be added or subtracted for each modified packet.

		Returns:
			self: This instance with all currently retrieved modifier data using find and the newly added modifier data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the modifier data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ClusterSize=None, Enabled=None, L3MatchEtherType=None, L3MatchMode=None, L3MatchMplsLabel=None, L4MatchEncapsulation=None, L4MatchMode=None, L4MatchProtocolNumber=None, L5MatchEncapsulation=None, L5MatchMode=None, L5MatchPortNumber=None, Mask=None, MatchValue=None, MatchValueEnabled=None, Name=None, Offset=None, OffsetStart=None, PercentRate=None, ReplaceFixedValue=None, ReplaceMode=None, ReplaceRangeCount=None, ReplaceRangeDecrement=None, ReplaceRangeFirst=None, ReplaceRangeStep=None):
		"""Finds and retrieves modifier data from the server.

		All named parameters support regex and can be used to selectively retrieve modifier data from the server.
		By default the find method takes no parameters and will retrieve all modifier data from the server.

		Args:
			ClusterSize (number): Number of packets to modify on each occurrence. Default: 1.
			Enabled (bool): If true, modify incoming packets.
			L3MatchEtherType (str): EtherType value to match.
			L3MatchMode (str(matchAny|matchBottomMplsLabel|matchEtherType)): For an L3 offset, specify whether to modify only packets with a specific EtherType or bottom MPLS label.
			L3MatchMplsLabel (number): MPLS label to match.
			L4MatchEncapsulation (str(matchIpv4|matchIpv4OrIpv6|matchIpv6)): For an L4 offset, specify whether to modify IPv4 packets, IPv6 packets, or both.
			L4MatchMode (str(matchAny|matchProtocolNumber)): For an L4 offset, specify whether to modify only packets with a specific protocol number.
			L4MatchProtocolNumber (number): Protocol number to match.
			L5MatchEncapsulation (str(matchTcp|matchUdp)): For an L5 offset, specify whether to modify TCP packets only or UDP packets only.
			L5MatchMode (str(matchAny|matchDestinationPort|matchSourceOrDestinationPort|matchSourcePort)): For an L5 offset, specify whether to modify only packets with a specific source or destination port number.
			L5MatchPortNumber (number): Port number to match.
			Mask (str): Mask identifying the bits of the field to be modified, as a hex string with prefix 0x (e.g. 0xFF FF). The bits of the mask must be contiguous.
			MatchValue (str): Value to be matched. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).
			MatchValueEnabled (bool): Only modify packets if the existing field value matches a specified value.
			Name (str): Name of the modifier.
			Offset (number): The position of the field to be modified, as an offset in bytes.
			OffsetStart (str(l2Offset|l3Offset|l4Offset|l5Offset)): Define the position of the field to be modified, as an offset from a specified position. Default is from the start of the L2 header.
			PercentRate (number): How often to modify matching packets. Default: 100%.
			ReplaceFixedValue (str): Fixed replacement value. Format: MAC address, IPv4 address, IPv6 address, decimal value, binary string with prefix 0b (e.g. 0b0100), or a hex string with prefix 0x (e.g. 0xFF FF).
			ReplaceMode (str(fixedValue|range)): Replace field with a fixed value or a range of values.
			ReplaceRangeCount (str): Number of values in range. Can be any value up to ceiling(2^width / step), where width is the width of the field mask.
			ReplaceRangeDecrement (bool): Decrement instead of incrementing. Default: false.
			ReplaceRangeFirst (str): Start of range.
			ReplaceRangeStep (str): Step to be added or subtracted for each modified packet.

		Returns:
			self: This instance with matching modifier data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of modifier data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the modifier data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Mp(Base):
	"""The Mp class encapsulates a user managed mp node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Mp property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'mp'

	def __init__(self, parent):
		super(Mp, self).__init__(parent)

	@property
	def AddCcmCustomTlvs(self):
		"""If true, adds a custom CCM TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addCcmCustomTlvs')
	@AddCcmCustomTlvs.setter
	def AddCcmCustomTlvs(self, value):
		self._set_attribute('addCcmCustomTlvs', value)

	@property
	def AddDataTlv(self):
		"""If true, adds a data TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addDataTlv')
	@AddDataTlv.setter
	def AddDataTlv(self, value):
		self._set_attribute('addDataTlv', value)

	@property
	def AddInterfaceStatusTlv(self):
		"""If true, adds an interface status TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addInterfaceStatusTlv')
	@AddInterfaceStatusTlv.setter
	def AddInterfaceStatusTlv(self, value):
		self._set_attribute('addInterfaceStatusTlv', value)

	@property
	def AddLbmCustomTlvs(self):
		"""If true, adds a custom loopback message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addLbmCustomTlvs')
	@AddLbmCustomTlvs.setter
	def AddLbmCustomTlvs(self, value):
		self._set_attribute('addLbmCustomTlvs', value)

	@property
	def AddLbrCustomTlvs(self):
		"""If true, adds a custom loopback response message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addLbrCustomTlvs')
	@AddLbrCustomTlvs.setter
	def AddLbrCustomTlvs(self, value):
		self._set_attribute('addLbrCustomTlvs', value)

	@property
	def AddLmmCustomTlvs(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('addLmmCustomTlvs')
	@AddLmmCustomTlvs.setter
	def AddLmmCustomTlvs(self, value):
		self._set_attribute('addLmmCustomTlvs', value)

	@property
	def AddLmrCustomTlvs(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('addLmrCustomTlvs')
	@AddLmrCustomTlvs.setter
	def AddLmrCustomTlvs(self, value):
		self._set_attribute('addLmrCustomTlvs', value)

	@property
	def AddLtmCustomTlvs(self):
		"""If true, adds a custom link trace message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addLtmCustomTlvs')
	@AddLtmCustomTlvs.setter
	def AddLtmCustomTlvs(self, value):
		self._set_attribute('addLtmCustomTlvs', value)

	@property
	def AddLtrCustomTlvs(self):
		"""If true, adds a custom link trace message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addLtrCustomTlvs')
	@AddLtrCustomTlvs.setter
	def AddLtrCustomTlvs(self, value):
		self._set_attribute('addLtrCustomTlvs', value)

	@property
	def AddOrganizationSpecificTlv(self):
		"""If true, adds a custom organization specific message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addOrganizationSpecificTlv')
	@AddOrganizationSpecificTlv.setter
	def AddOrganizationSpecificTlv(self, value):
		self._set_attribute('addOrganizationSpecificTlv', value)

	@property
	def AddPortStatusTlv(self):
		"""If true, adds a custom port statust message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addPortStatusTlv')
	@AddPortStatusTlv.setter
	def AddPortStatusTlv(self, value):
		self._set_attribute('addPortStatusTlv', value)

	@property
	def AddSenderIdTlv(self):
		"""If true, adds a custom sender ID message TLV to bridge messages.

		Returns:
			bool
		"""
		return self._get_attribute('addSenderIdTlv')
	@AddSenderIdTlv.setter
	def AddSenderIdTlv(self, value):
		self._set_attribute('addSenderIdTlv', value)

	@property
	def AisEnableUnicastMac(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('aisEnableUnicastMac')
	@AisEnableUnicastMac.setter
	def AisEnableUnicastMac(self, value):
		self._set_attribute('aisEnableUnicastMac', value)

	@property
	def AisInterval(self):
		"""NOT DEFINED

		Returns:
			str(oneSec|oneMin)
		"""
		return self._get_attribute('aisInterval')
	@AisInterval.setter
	def AisInterval(self, value):
		self._set_attribute('aisInterval', value)

	@property
	def AisMode(self):
		"""NOT DEFINED

		Returns:
			str(auto|start|stop)
		"""
		return self._get_attribute('aisMode')
	@AisMode.setter
	def AisMode(self, value):
		self._set_attribute('aisMode', value)

	@property
	def AisPriority(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('aisPriority')
	@AisPriority.setter
	def AisPriority(self, value):
		self._set_attribute('aisPriority', value)

	@property
	def AisUnicastMac(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('aisUnicastMac')
	@AisUnicastMac.setter
	def AisUnicastMac(self, value):
		self._set_attribute('aisUnicastMac', value)

	@property
	def AutoDmAllDestination(self):
		"""If true, enables the automatic sending of DM Messages.

		Returns:
			bool
		"""
		return self._get_attribute('autoDmAllDestination')
	@AutoDmAllDestination.setter
	def AutoDmAllDestination(self, value):
		self._set_attribute('autoDmAllDestination', value)

	@property
	def AutoDmDestination(self):
		"""The sent MAC address for the DM, if autoDmAllDestination is set to true.

		Returns:
			str
		"""
		return self._get_attribute('autoDmDestination')
	@AutoDmDestination.setter
	def AutoDmDestination(self, value):
		self._set_attribute('autoDmDestination', value)

	@property
	def AutoDmIteration(self):
		"""The count for how many times DMMs will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32

		Returns:
			number
		"""
		return self._get_attribute('autoDmIteration')
	@AutoDmIteration.setter
	def AutoDmIteration(self, value):
		self._set_attribute('autoDmIteration', value)

	@property
	def AutoDmTimeout(self):
		"""The timeout period in seconds to wait for a response to DMMs. This value should be less than the Auto LB Timer. Default is 30. Min: 1 Max: 65535

		Returns:
			number
		"""
		return self._get_attribute('autoDmTimeout')
	@AutoDmTimeout.setter
	def AutoDmTimeout(self, value):
		self._set_attribute('autoDmTimeout', value)

	@property
	def AutoDmTimer(self):
		"""The time period in seconds between DMMs. Default is 60. Min: 1 Max: 65535

		Returns:
			number
		"""
		return self._get_attribute('autoDmTimer')
	@AutoDmTimer.setter
	def AutoDmTimer(self, value):
		self._set_attribute('autoDmTimer', value)

	@property
	def AutoLbAllDestination(self):
		"""If true, enables the automatic sending of Loopback Messages.

		Returns:
			bool
		"""
		return self._get_attribute('autoLbAllDestination')
	@AutoLbAllDestination.setter
	def AutoLbAllDestination(self, value):
		self._set_attribute('autoLbAllDestination', value)

	@property
	def AutoLbDestination(self):
		"""Sets the loopback destination MAC address.

		Returns:
			str
		"""
		return self._get_attribute('autoLbDestination')
	@AutoLbDestination.setter
	def AutoLbDestination(self, value):
		self._set_attribute('autoLbDestination', value)

	@property
	def AutoLbIteration(self):
		"""The count for how many times LBM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32

		Returns:
			number
		"""
		return self._get_attribute('autoLbIteration')
	@AutoLbIteration.setter
	def AutoLbIteration(self, value):
		self._set_attribute('autoLbIteration', value)

	@property
	def AutoLbTimeout(self):
		"""The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535

		Returns:
			number
		"""
		return self._get_attribute('autoLbTimeout')
	@AutoLbTimeout.setter
	def AutoLbTimeout(self, value):
		self._set_attribute('autoLbTimeout', value)

	@property
	def AutoLbTimer(self):
		"""The time period in seconds between LBMs. Default is 60. Min: 1 Max: 65535

		Returns:
			number
		"""
		return self._get_attribute('autoLbTimer')
	@AutoLbTimer.setter
	def AutoLbTimer(self, value):
		self._set_attribute('autoLbTimer', value)

	@property
	def AutoLmIteration(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('autoLmIteration')
	@AutoLmIteration.setter
	def AutoLmIteration(self, value):
		self._set_attribute('autoLmIteration', value)

	@property
	def AutoLmTimeout(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('autoLmTimeout')
	@AutoLmTimeout.setter
	def AutoLmTimeout(self, value):
		self._set_attribute('autoLmTimeout', value)

	@property
	def AutoLmTimer(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('autoLmTimer')
	@AutoLmTimer.setter
	def AutoLmTimer(self, value):
		self._set_attribute('autoLmTimer', value)

	@property
	def AutoLtAllDestination(self):
		"""If true, enables the automatic sending to Link Trace Messages.

		Returns:
			bool
		"""
		return self._get_attribute('autoLtAllDestination')
	@AutoLtAllDestination.setter
	def AutoLtAllDestination(self, value):
		self._set_attribute('autoLtAllDestination', value)

	@property
	def AutoLtDestination(self):
		"""Sets the link trance destination MAC address.

		Returns:
			str
		"""
		return self._get_attribute('autoLtDestination')
	@AutoLtDestination.setter
	def AutoLtDestination(self, value):
		self._set_attribute('autoLtDestination', value)

	@property
	def AutoLtIteration(self):
		"""The count for how many times LTM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32

		Returns:
			number
		"""
		return self._get_attribute('autoLtIteration')
	@AutoLtIteration.setter
	def AutoLtIteration(self, value):
		self._set_attribute('autoLtIteration', value)

	@property
	def AutoLtTimeout(self):
		"""The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535

		Returns:
			number
		"""
		return self._get_attribute('autoLtTimeout')
	@AutoLtTimeout.setter
	def AutoLtTimeout(self, value):
		self._set_attribute('autoLtTimeout', value)

	@property
	def AutoLtTimer(self):
		"""The time period in seconds between LTMs. Default is 60. Min: 1 Max: 65535

		Returns:
			number
		"""
		return self._get_attribute('autoLtTimer')
	@AutoLtTimer.setter
	def AutoLtTimer(self, value):
		self._set_attribute('autoLtTimer', value)

	@property
	def CciInterval(self):
		"""Sets the Continuity Check Interval (CCI).

		Returns:
			str(3.33msec|10msec|100msec|1sec|10sec|1min|10min)
		"""
		return self._get_attribute('cciInterval')
	@CciInterval.setter
	def CciInterval(self, value):
		self._set_attribute('cciInterval', value)

	@property
	def CcmLmmTxFcf(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ccmLmmTxFcf')
	@CcmLmmTxFcf.setter
	def CcmLmmTxFcf(self, value):
		self._set_attribute('ccmLmmTxFcf', value)

	@property
	def CcmLmmTxFcfStep(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ccmLmmTxFcfStep')
	@CcmLmmTxFcfStep.setter
	def CcmLmmTxFcfStep(self, value):
		self._set_attribute('ccmLmmTxFcfStep', value)

	@property
	def CcmPriority(self):
		"""Sets the priority for Continuity Check Messages. The default is 0. Min: 0 Max: 7

		Returns:
			number
		"""
		return self._get_attribute('ccmPriority')
	@CcmPriority.setter
	def CcmPriority(self, value):
		self._set_attribute('ccmPriority', value)

	@property
	def CcmRxFcb(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ccmRxFcb')
	@CcmRxFcb.setter
	def CcmRxFcb(self, value):
		self._set_attribute('ccmRxFcb', value)

	@property
	def CcmRxFcbStep(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ccmRxFcbStep')
	@CcmRxFcbStep.setter
	def CcmRxFcbStep(self, value):
		self._set_attribute('ccmRxFcbStep', value)

	@property
	def ChassisId(self):
		"""Sets the chassis identification. Default is 00 00 00 00 00 00. This will take Hex value as input (0-255 byte).

		Returns:
			str
		"""
		return self._get_attribute('chassisId')
	@ChassisId.setter
	def ChassisId(self, value):
		self._set_attribute('chassisId', value)

	@property
	def ChassisIdLength(self):
		"""Sets the length of the Chassis ID field. Default is 6. Min: 0 Max: 255.

		Returns:
			number
		"""
		return self._get_attribute('chassisIdLength')
	@ChassisIdLength.setter
	def ChassisIdLength(self, value):
		self._set_attribute('chassisIdLength', value)

	@property
	def ChassisIdSubType(self):
		"""Sets the chassis identifier sub-type for the optional TLV messages. Options are:

		Returns:
			str(chassisComponent|interfaceAlias|portComponent|macAddress|networkAddress|interfaceName|locallyAssigned)
		"""
		return self._get_attribute('chassisIdSubType')
	@ChassisIdSubType.setter
	def ChassisIdSubType(self, value):
		self._set_attribute('chassisIdSubType', value)

	@property
	def DataTlvLength(self):
		"""Sets the length of the Data TLV field. Default is 4. Min: 0 Max: 1500.

		Returns:
			number
		"""
		return self._get_attribute('dataTlvLength')
	@DataTlvLength.setter
	def DataTlvLength(self, value):
		self._set_attribute('dataTlvLength', value)

	@property
	def DataTlvValue(self):
		"""This attribute will take Hex value of data. This data TLV will be added both for periodic LBM and requested LBM transmit. Default is 44 61 74 61.

		Returns:
			str
		"""
		return self._get_attribute('dataTlvValue')
	@DataTlvValue.setter
	def DataTlvValue(self, value):
		self._set_attribute('dataTlvValue', value)

	@property
	def DmMethod(self):
		"""The type of Delay Measurment support.

		Returns:
			str(twoWay|oneWay)
		"""
		return self._get_attribute('dmMethod')
	@DmMethod.setter
	def DmMethod(self, value):
		self._set_attribute('dmMethod', value)

	@property
	def DmPriority(self):
		"""Sets the priority for DM Messages. This priority will be used only for periodic DMMs one-way or two-way (for both type of DM Methodfor each MIP). The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('dmPriority')
	@DmPriority.setter
	def DmPriority(self, value):
		self._set_attribute('dmPriority', value)

	@property
	def DmmPriority(self):
		"""DEPRECATED Sets the priority for DM Messages. This priority will be used only for periodic DMMs. The default is 0. Min: 0 Max: 7

		Returns:
			number
		"""
		return self._get_attribute('dmmPriority')
	@DmmPriority.setter
	def DmmPriority(self, value):
		self._set_attribute('dmmPriority', value)

	@property
	def EnableAisRx(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableAisRx')
	@EnableAisRx.setter
	def EnableAisRx(self, value):
		self._set_attribute('enableAisRx', value)

	@property
	def EnableAutoDm(self):
		"""DEPRECATED If true, enables the automatic sending of DM Messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoDm')
	@EnableAutoDm.setter
	def EnableAutoDm(self, value):
		self._set_attribute('enableAutoDm', value)

	@property
	def EnableAutoLb(self):
		"""DEPRECATED If true, enables the automatic sending of Loopback messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoLb')
	@EnableAutoLb.setter
	def EnableAutoLb(self, value):
		self._set_attribute('enableAutoLb', value)

	@property
	def EnableAutoLm(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoLm')
	@EnableAutoLm.setter
	def EnableAutoLm(self, value):
		self._set_attribute('enableAutoLm', value)

	@property
	def EnableAutoLt(self):
		"""DEPRECATED If true, enables the automatic sending of Link Trace messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoLt')
	@EnableAutoLt.setter
	def EnableAutoLt(self, value):
		self._set_attribute('enableAutoLt', value)

	@property
	def EnableLckRx(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLckRx')
	@EnableLckRx.setter
	def EnableLckRx(self, value):
		self._set_attribute('enableLckRx', value)

	@property
	def EnableLmCounterUpdate(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLmCounterUpdate')
	@EnableLmCounterUpdate.setter
	def EnableLmCounterUpdate(self, value):
		self._set_attribute('enableLmCounterUpdate', value)

	@property
	def EnableTstRx(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableTstRx')
	@EnableTstRx.setter
	def EnableTstRx(self, value):
		self._set_attribute('enableTstRx', value)

	@property
	def Enabled(self):
		"""DEPRECATED If true, the MP is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def InterRemoteMepRxIncrementStep(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('interRemoteMepRxIncrementStep')
	@InterRemoteMepRxIncrementStep.setter
	def InterRemoteMepRxIncrementStep(self, value):
		self._set_attribute('interRemoteMepRxIncrementStep', value)

	@property
	def InterRemoteMepTxIncrementStep(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('interRemoteMepTxIncrementStep')
	@InterRemoteMepTxIncrementStep.setter
	def InterRemoteMepTxIncrementStep(self, value):
		self._set_attribute('interRemoteMepTxIncrementStep', value)

	@property
	def LbmPriority(self):
		"""DEPRECATED Sets the priority for Loopback Messages. This priority will be used only for periodic LBMs. The default is 0. Min: 0 Max: 7

		Returns:
			number
		"""
		return self._get_attribute('lbmPriority')
	@LbmPriority.setter
	def LbmPriority(self, value):
		self._set_attribute('lbmPriority', value)

	@property
	def LckEnableUnicastMac(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('lckEnableUnicastMac')
	@LckEnableUnicastMac.setter
	def LckEnableUnicastMac(self, value):
		self._set_attribute('lckEnableUnicastMac', value)

	@property
	def LckInterval(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(oneSec|oneMin)
		"""
		return self._get_attribute('lckInterval')
	@LckInterval.setter
	def LckInterval(self, value):
		self._set_attribute('lckInterval', value)

	@property
	def LckMode(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(auto|start|stop)
		"""
		return self._get_attribute('lckMode')
	@LckMode.setter
	def LckMode(self, value):
		self._set_attribute('lckMode', value)

	@property
	def LckPriority(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('lckPriority')
	@LckPriority.setter
	def LckPriority(self, value):
		self._set_attribute('lckPriority', value)

	@property
	def LckSupportAisGeneration(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('lckSupportAisGeneration')
	@LckSupportAisGeneration.setter
	def LckSupportAisGeneration(self, value):
		self._set_attribute('lckSupportAisGeneration', value)

	@property
	def LckUnicastMac(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('lckUnicastMac')
	@LckUnicastMac.setter
	def LckUnicastMac(self, value):
		self._set_attribute('lckUnicastMac', value)

	@property
	def LmAllRemoteMeps(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('lmAllRemoteMeps')
	@LmAllRemoteMeps.setter
	def LmAllRemoteMeps(self, value):
		self._set_attribute('lmAllRemoteMeps', value)

	@property
	def LmDestinationMacAddress(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('lmDestinationMacAddress')
	@LmDestinationMacAddress.setter
	def LmDestinationMacAddress(self, value):
		self._set_attribute('lmDestinationMacAddress', value)

	@property
	def LmMethod(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(singleEnded|dualEnded)
		"""
		return self._get_attribute('lmMethod')
	@LmMethod.setter
	def LmMethod(self, value):
		self._set_attribute('lmMethod', value)

	@property
	def LmmPriority(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('lmmPriority')
	@LmmPriority.setter
	def LmmPriority(self, value):
		self._set_attribute('lmmPriority', value)

	@property
	def LmrPriority(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('lmrPriority')
	@LmrPriority.setter
	def LmrPriority(self, value):
		self._set_attribute('lmrPriority', value)

	@property
	def LmrRxFcf(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('lmrRxFcf')
	@LmrRxFcf.setter
	def LmrRxFcf(self, value):
		self._set_attribute('lmrRxFcf', value)

	@property
	def LmrRxFcfStep(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('lmrRxFcfStep')
	@LmrRxFcfStep.setter
	def LmrRxFcfStep(self, value):
		self._set_attribute('lmrRxFcfStep', value)

	@property
	def LtmPriority(self):
		"""DEPRECATED Sets the priority for Link Trace Messages. This priority will be used only for periodic LTMs. The default is 0. Min: 0 Max: 7

		Returns:
			number
		"""
		return self._get_attribute('ltmPriority')
	@LtmPriority.setter
	def LtmPriority(self, value):
		self._set_attribute('ltmPriority', value)

	@property
	def MacAddress(self):
		"""DEPRECATED The MAC address of the MP.

		Returns:
			str
		"""
		return self._get_attribute('macAddress')
	@MacAddress.setter
	def MacAddress(self, value):
		self._set_attribute('macAddress', value)

	@property
	def ManagementAddress(self):
		"""DEPRECATED Sets the MP management address. Input type is HEX (0-255 byte). Default is 01 02 03 03 04 05.

		Returns:
			str
		"""
		return self._get_attribute('managementAddress')
	@ManagementAddress.setter
	def ManagementAddress(self, value):
		self._set_attribute('managementAddress', value)

	@property
	def ManagementAddressDomain(self):
		"""DEPRECATED Sets the MP management address domain. This will take HEX input (0-255 byte). Default is 4d 61 6e 61 67 65 6d 65 6e 74 20 41 64 64 72 20 44 6f 6d 61 69 6e (Management Addr Domain).

		Returns:
			str
		"""
		return self._get_attribute('managementAddressDomain')
	@ManagementAddressDomain.setter
	def ManagementAddressDomain(self, value):
		self._set_attribute('managementAddressDomain', value)

	@property
	def ManagementAddressDomainLength(self):
		"""DEPRECATED Sets the length of the Management address domain field. Default is 22. Min: 0 Max: 255.

		Returns:
			number
		"""
		return self._get_attribute('managementAddressDomainLength')
	@ManagementAddressDomainLength.setter
	def ManagementAddressDomainLength(self, value):
		self._set_attribute('managementAddressDomainLength', value)

	@property
	def ManagementAddressLength(self):
		"""DEPRECATED Sets the length of the Management address field. Default is 6. Min: 0 Max: 255.

		Returns:
			number
		"""
		return self._get_attribute('managementAddressLength')
	@ManagementAddressLength.setter
	def ManagementAddressLength(self, value):
		self._set_attribute('managementAddressLength', value)

	@property
	def MdLevel(self):
		"""DEPRECATED The MD level of the MP. The MD level must be previously configured.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=mdLevel)
		"""
		return self._get_attribute('mdLevel')
	@MdLevel.setter
	def MdLevel(self, value):
		self._set_attribute('mdLevel', value)

	@property
	def MegId(self):
		"""DEPRECATED The MEG identifier of the MP. This is for use with ITU-T Y.1731.

		Returns:
			str
		"""
		return self._get_attribute('megId')
	@MegId.setter
	def MegId(self, value):
		self._set_attribute('megId', value)

	@property
	def MegIdFormat(self):
		"""DEPRECATED The MEG identifier format.

		Returns:
			str(iccBasedFormat|primaryVid|characterString|2octetInteger|rfc2685VpnId)
		"""
		return self._get_attribute('megIdFormat')
	@MegIdFormat.setter
	def MegIdFormat(self, value):
		self._set_attribute('megIdFormat', value)

	@property
	def MepId(self):
		"""DEPRECATED The MEP identifier.

		Returns:
			number
		"""
		return self._get_attribute('mepId')
	@MepId.setter
	def MepId(self, value):
		self._set_attribute('mepId', value)

	@property
	def MipId(self):
		"""DEPRECATED The MIP identifier.

		Returns:
			number
		"""
		return self._get_attribute('mipId')
	@MipId.setter
	def MipId(self, value):
		self._set_attribute('mipId', value)

	@property
	def MpType(self):
		"""DEPRECATED Sets the MP type.

		Returns:
			str(mip|mep)
		"""
		return self._get_attribute('mpType')
	@MpType.setter
	def MpType(self, value):
		self._set_attribute('mpType', value)

	@property
	def OrganizationSpecificTlvLength(self):
		"""DEPRECATED Sets the length of the organizational specific TLV field. Default is 4. Min: 4 Max: 1500

		Returns:
			number
		"""
		return self._get_attribute('organizationSpecificTlvLength')
	@OrganizationSpecificTlvLength.setter
	def OrganizationSpecificTlvLength(self, value):
		self._set_attribute('organizationSpecificTlvLength', value)

	@property
	def OrganizationSpecificTlvValue(self):
		"""DEPRECATED Sets the value of the organizational specific TLV field. This attribute will take Hex value. Default is NULL.

		Returns:
			str
		"""
		return self._get_attribute('organizationSpecificTlvValue')
	@OrganizationSpecificTlvValue.setter
	def OrganizationSpecificTlvValue(self, value):
		self._set_attribute('organizationSpecificTlvValue', value)

	@property
	def OverrideVlanPriority(self):
		"""DEPRECATED If true, overrides the set VLAN priority for this bridge, and uses the advanced settings instead.

		Returns:
			bool
		"""
		return self._get_attribute('overrideVlanPriority')
	@OverrideVlanPriority.setter
	def OverrideVlanPriority(self, value):
		self._set_attribute('overrideVlanPriority', value)

	@property
	def Rdi(self):
		"""DEPRECATED The Remote Defect Identification.

		Returns:
			str(auto|on|off)
		"""
		return self._get_attribute('rdi')
	@Rdi.setter
	def Rdi(self, value):
		self._set_attribute('rdi', value)

	@property
	def ShortMaName(self):
		"""DEPRECATED Sets the Short MA name. The format is determined in shortMaNameFormat. This is used with IEEE 802.1ag.

		Returns:
			str
		"""
		return self._get_attribute('shortMaName')
	@ShortMaName.setter
	def ShortMaName(self, value):
		self._set_attribute('shortMaName', value)

	@property
	def ShortMaNameFormat(self):
		"""DEPRECATED Sets the Short MA Name format.

		Returns:
			str(primaryVid|characterString|2octetInteger|rfc2685VpnId)
		"""
		return self._get_attribute('shortMaNameFormat')
	@ShortMaNameFormat.setter
	def ShortMaNameFormat(self, value):
		self._set_attribute('shortMaNameFormat', value)

	@property
	def TstEnableUnicastMac(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('tstEnableUnicastMac')
	@TstEnableUnicastMac.setter
	def TstEnableUnicastMac(self, value):
		self._set_attribute('tstEnableUnicastMac', value)

	@property
	def TstIncrPacketLength(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('tstIncrPacketLength')
	@TstIncrPacketLength.setter
	def TstIncrPacketLength(self, value):
		self._set_attribute('tstIncrPacketLength', value)

	@property
	def TstIncrPacketLengthStep(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tstIncrPacketLengthStep')
	@TstIncrPacketLengthStep.setter
	def TstIncrPacketLengthStep(self, value):
		self._set_attribute('tstIncrPacketLengthStep', value)

	@property
	def TstInitialPatternValue(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tstInitialPatternValue')
	@TstInitialPatternValue.setter
	def TstInitialPatternValue(self, value):
		self._set_attribute('tstInitialPatternValue', value)

	@property
	def TstInterval(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tstInterval')
	@TstInterval.setter
	def TstInterval(self, value):
		self._set_attribute('tstInterval', value)

	@property
	def TstMode(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(start|stop)
		"""
		return self._get_attribute('tstMode')
	@TstMode.setter
	def TstMode(self, value):
		self._set_attribute('tstMode', value)

	@property
	def TstOverwriteSequenceNumber(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('tstOverwriteSequenceNumber')
	@TstOverwriteSequenceNumber.setter
	def TstOverwriteSequenceNumber(self, value):
		self._set_attribute('tstOverwriteSequenceNumber', value)

	@property
	def TstPacketLength(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tstPacketLength')
	@TstPacketLength.setter
	def TstPacketLength(self, value):
		self._set_attribute('tstPacketLength', value)

	@property
	def TstPatternType(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(nullSignalWithoutCrc32|nullSignalWithCrc32|prbs2311WithoutCrc32|prbs2311WithCrc32)
		"""
		return self._get_attribute('tstPatternType')
	@TstPatternType.setter
	def TstPatternType(self, value):
		self._set_attribute('tstPatternType', value)

	@property
	def TstPriority(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tstPriority')
	@TstPriority.setter
	def TstPriority(self, value):
		self._set_attribute('tstPriority', value)

	@property
	def TstSequenceNumber(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tstSequenceNumber')
	@TstSequenceNumber.setter
	def TstSequenceNumber(self, value):
		self._set_attribute('tstSequenceNumber', value)

	@property
	def TstTestType(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(inService|outOfService)
		"""
		return self._get_attribute('tstTestType')
	@TstTestType.setter
	def TstTestType(self, value):
		self._set_attribute('tstTestType', value)

	@property
	def TstUnicastMac(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('tstUnicastMac')
	@TstUnicastMac.setter
	def TstUnicastMac(self, value):
		self._set_attribute('tstUnicastMac', value)

	@property
	def Ttl(self):
		"""DEPRECATED Sets the MP Time-to-live value. Default is 64. Min: 1 Max: 255

		Returns:
			number
		"""
		return self._get_attribute('ttl')
	@Ttl.setter
	def Ttl(self, value):
		self._set_attribute('ttl', value)

	@property
	def Vlan(self):
		"""DEPRECATED Assigns a VLAN to the MP. The VLAN must be previously configured.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=vlans)
		"""
		return self._get_attribute('vlan')
	@Vlan.setter
	def Vlan(self, value):
		self._set_attribute('vlan', value)

	def update(self, AddCcmCustomTlvs=None, AddDataTlv=None, AddInterfaceStatusTlv=None, AddLbmCustomTlvs=None, AddLbrCustomTlvs=None, AddLmmCustomTlvs=None, AddLmrCustomTlvs=None, AddLtmCustomTlvs=None, AddLtrCustomTlvs=None, AddOrganizationSpecificTlv=None, AddPortStatusTlv=None, AddSenderIdTlv=None, AisEnableUnicastMac=None, AisInterval=None, AisMode=None, AisPriority=None, AisUnicastMac=None, AutoDmAllDestination=None, AutoDmDestination=None, AutoDmIteration=None, AutoDmTimeout=None, AutoDmTimer=None, AutoLbAllDestination=None, AutoLbDestination=None, AutoLbIteration=None, AutoLbTimeout=None, AutoLbTimer=None, AutoLmIteration=None, AutoLmTimeout=None, AutoLmTimer=None, AutoLtAllDestination=None, AutoLtDestination=None, AutoLtIteration=None, AutoLtTimeout=None, AutoLtTimer=None, CciInterval=None, CcmLmmTxFcf=None, CcmLmmTxFcfStep=None, CcmPriority=None, CcmRxFcb=None, CcmRxFcbStep=None, ChassisId=None, ChassisIdLength=None, ChassisIdSubType=None, DataTlvLength=None, DataTlvValue=None, DmMethod=None, DmPriority=None, DmmPriority=None, EnableAisRx=None, EnableAutoDm=None, EnableAutoLb=None, EnableAutoLm=None, EnableAutoLt=None, EnableLckRx=None, EnableLmCounterUpdate=None, EnableTstRx=None, Enabled=None, InterRemoteMepRxIncrementStep=None, InterRemoteMepTxIncrementStep=None, LbmPriority=None, LckEnableUnicastMac=None, LckInterval=None, LckMode=None, LckPriority=None, LckSupportAisGeneration=None, LckUnicastMac=None, LmAllRemoteMeps=None, LmDestinationMacAddress=None, LmMethod=None, LmmPriority=None, LmrPriority=None, LmrRxFcf=None, LmrRxFcfStep=None, LtmPriority=None, MacAddress=None, ManagementAddress=None, ManagementAddressDomain=None, ManagementAddressDomainLength=None, ManagementAddressLength=None, MdLevel=None, MegId=None, MegIdFormat=None, MepId=None, MipId=None, MpType=None, OrganizationSpecificTlvLength=None, OrganizationSpecificTlvValue=None, OverrideVlanPriority=None, Rdi=None, ShortMaName=None, ShortMaNameFormat=None, TstEnableUnicastMac=None, TstIncrPacketLength=None, TstIncrPacketLengthStep=None, TstInitialPatternValue=None, TstInterval=None, TstMode=None, TstOverwriteSequenceNumber=None, TstPacketLength=None, TstPatternType=None, TstPriority=None, TstSequenceNumber=None, TstTestType=None, TstUnicastMac=None, Ttl=None, Vlan=None):
		"""Updates a child instance of mp on the server.

		Args:
			AddCcmCustomTlvs (bool): If true, adds a custom CCM TLV to bridge messages.
			AddDataTlv (bool): If true, adds a data TLV to bridge messages.
			AddInterfaceStatusTlv (bool): If true, adds an interface status TLV to bridge messages.
			AddLbmCustomTlvs (bool): If true, adds a custom loopback message TLV to bridge messages.
			AddLbrCustomTlvs (bool): If true, adds a custom loopback response message TLV to bridge messages.
			AddLmmCustomTlvs (bool): NOT DEFINED
			AddLmrCustomTlvs (bool): NOT DEFINED
			AddLtmCustomTlvs (bool): If true, adds a custom link trace message TLV to bridge messages.
			AddLtrCustomTlvs (bool): If true, adds a custom link trace message TLV to bridge messages.
			AddOrganizationSpecificTlv (bool): If true, adds a custom organization specific message TLV to bridge messages.
			AddPortStatusTlv (bool): If true, adds a custom port statust message TLV to bridge messages.
			AddSenderIdTlv (bool): If true, adds a custom sender ID message TLV to bridge messages.
			AisEnableUnicastMac (bool): NOT DEFINED
			AisInterval (str(oneSec|oneMin)): NOT DEFINED
			AisMode (str(auto|start|stop)): NOT DEFINED
			AisPriority (number): NOT DEFINED
			AisUnicastMac (str): NOT DEFINED
			AutoDmAllDestination (bool): If true, enables the automatic sending of DM Messages.
			AutoDmDestination (str): The sent MAC address for the DM, if autoDmAllDestination is set to true.
			AutoDmIteration (number): The count for how many times DMMs will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoDmTimeout (number): The timeout period in seconds to wait for a response to DMMs. This value should be less than the Auto LB Timer. Default is 30. Min: 1 Max: 65535
			AutoDmTimer (number): The time period in seconds between DMMs. Default is 60. Min: 1 Max: 65535
			AutoLbAllDestination (bool): If true, enables the automatic sending of Loopback Messages.
			AutoLbDestination (str): Sets the loopback destination MAC address.
			AutoLbIteration (number): The count for how many times LBM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoLbTimeout (number): The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535
			AutoLbTimer (number): The time period in seconds between LBMs. Default is 60. Min: 1 Max: 65535
			AutoLmIteration (number): NOT DEFINED
			AutoLmTimeout (number): NOT DEFINED
			AutoLmTimer (number): NOT DEFINED
			AutoLtAllDestination (bool): If true, enables the automatic sending to Link Trace Messages.
			AutoLtDestination (str): Sets the link trance destination MAC address.
			AutoLtIteration (number): The count for how many times LTM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoLtTimeout (number): The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535
			AutoLtTimer (number): The time period in seconds between LTMs. Default is 60. Min: 1 Max: 65535
			CciInterval (str(3.33msec|10msec|100msec|1sec|10sec|1min|10min)): Sets the Continuity Check Interval (CCI).
			CcmLmmTxFcf (number): NOT DEFINED
			CcmLmmTxFcfStep (number): NOT DEFINED
			CcmPriority (number): Sets the priority for Continuity Check Messages. The default is 0. Min: 0 Max: 7
			CcmRxFcb (number): NOT DEFINED
			CcmRxFcbStep (number): NOT DEFINED
			ChassisId (str): Sets the chassis identification. Default is 00 00 00 00 00 00. This will take Hex value as input (0-255 byte).
			ChassisIdLength (number): Sets the length of the Chassis ID field. Default is 6. Min: 0 Max: 255.
			ChassisIdSubType (str(chassisComponent|interfaceAlias|portComponent|macAddress|networkAddress|interfaceName|locallyAssigned)): Sets the chassis identifier sub-type for the optional TLV messages. Options are:
			DataTlvLength (number): Sets the length of the Data TLV field. Default is 4. Min: 0 Max: 1500.
			DataTlvValue (str): This attribute will take Hex value of data. This data TLV will be added both for periodic LBM and requested LBM transmit. Default is 44 61 74 61.
			DmMethod (str(twoWay|oneWay)): The type of Delay Measurment support.
			DmPriority (number): Sets the priority for DM Messages. This priority will be used only for periodic DMMs one-way or two-way (for both type of DM Methodfor each MIP). The default is 0.
			DmmPriority (number): Sets the priority for DM Messages. This priority will be used only for periodic DMMs. The default is 0. Min: 0 Max: 7
			EnableAisRx (bool): NOT DEFINED
			EnableAutoDm (bool): If true, enables the automatic sending of DM Messages.
			EnableAutoLb (bool): If true, enables the automatic sending of Loopback messages.
			EnableAutoLm (bool): NOT DEFINED
			EnableAutoLt (bool): If true, enables the automatic sending of Link Trace messages.
			EnableLckRx (bool): NOT DEFINED
			EnableLmCounterUpdate (bool): NOT DEFINED
			EnableTstRx (bool): NOT DEFINED
			Enabled (bool): If true, the MP is enabled.
			InterRemoteMepRxIncrementStep (number): NOT DEFINED
			InterRemoteMepTxIncrementStep (number): NOT DEFINED
			LbmPriority (number): Sets the priority for Loopback Messages. This priority will be used only for periodic LBMs. The default is 0. Min: 0 Max: 7
			LckEnableUnicastMac (bool): NOT DEFINED
			LckInterval (str(oneSec|oneMin)): NOT DEFINED
			LckMode (str(auto|start|stop)): NOT DEFINED
			LckPriority (number): NOT DEFINED
			LckSupportAisGeneration (bool): NOT DEFINED
			LckUnicastMac (str): NOT DEFINED
			LmAllRemoteMeps (bool): NOT DEFINED
			LmDestinationMacAddress (str): NOT DEFINED
			LmMethod (str(singleEnded|dualEnded)): NOT DEFINED
			LmmPriority (number): NOT DEFINED
			LmrPriority (number): NOT DEFINED
			LmrRxFcf (number): NOT DEFINED
			LmrRxFcfStep (number): NOT DEFINED
			LtmPriority (number): Sets the priority for Link Trace Messages. This priority will be used only for periodic LTMs. The default is 0. Min: 0 Max: 7
			MacAddress (str): The MAC address of the MP.
			ManagementAddress (str): Sets the MP management address. Input type is HEX (0-255 byte). Default is 01 02 03 03 04 05.
			ManagementAddressDomain (str): Sets the MP management address domain. This will take HEX input (0-255 byte). Default is 4d 61 6e 61 67 65 6d 65 6e 74 20 41 64 64 72 20 44 6f 6d 61 69 6e (Management Addr Domain).
			ManagementAddressDomainLength (number): Sets the length of the Management address domain field. Default is 22. Min: 0 Max: 255.
			ManagementAddressLength (number): Sets the length of the Management address field. Default is 6. Min: 0 Max: 255.
			MdLevel (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=mdLevel)): The MD level of the MP. The MD level must be previously configured.
			MegId (str): The MEG identifier of the MP. This is for use with ITU-T Y.1731.
			MegIdFormat (str(iccBasedFormat|primaryVid|characterString|2octetInteger|rfc2685VpnId)): The MEG identifier format.
			MepId (number): The MEP identifier.
			MipId (number): The MIP identifier.
			MpType (str(mip|mep)): Sets the MP type.
			OrganizationSpecificTlvLength (number): Sets the length of the organizational specific TLV field. Default is 4. Min: 4 Max: 1500
			OrganizationSpecificTlvValue (str): Sets the value of the organizational specific TLV field. This attribute will take Hex value. Default is NULL.
			OverrideVlanPriority (bool): If true, overrides the set VLAN priority for this bridge, and uses the advanced settings instead.
			Rdi (str(auto|on|off)): The Remote Defect Identification.
			ShortMaName (str): Sets the Short MA name. The format is determined in shortMaNameFormat. This is used with IEEE 802.1ag.
			ShortMaNameFormat (str(primaryVid|characterString|2octetInteger|rfc2685VpnId)): Sets the Short MA Name format.
			TstEnableUnicastMac (bool): NOT DEFINED
			TstIncrPacketLength (bool): NOT DEFINED
			TstIncrPacketLengthStep (number): NOT DEFINED
			TstInitialPatternValue (number): NOT DEFINED
			TstInterval (number): NOT DEFINED
			TstMode (str(start|stop)): NOT DEFINED
			TstOverwriteSequenceNumber (bool): NOT DEFINED
			TstPacketLength (number): NOT DEFINED
			TstPatternType (str(nullSignalWithoutCrc32|nullSignalWithCrc32|prbs2311WithoutCrc32|prbs2311WithCrc32)): NOT DEFINED
			TstPriority (number): NOT DEFINED
			TstSequenceNumber (number): NOT DEFINED
			TstTestType (str(inService|outOfService)): NOT DEFINED
			TstUnicastMac (str): NOT DEFINED
			Ttl (number): Sets the MP Time-to-live value. Default is 64. Min: 1 Max: 255
			Vlan (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=vlans)): Assigns a VLAN to the MP. The VLAN must be previously configured.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AddCcmCustomTlvs=None, AddDataTlv=None, AddInterfaceStatusTlv=None, AddLbmCustomTlvs=None, AddLbrCustomTlvs=None, AddLmmCustomTlvs=None, AddLmrCustomTlvs=None, AddLtmCustomTlvs=None, AddLtrCustomTlvs=None, AddOrganizationSpecificTlv=None, AddPortStatusTlv=None, AddSenderIdTlv=None, AisEnableUnicastMac=None, AisInterval=None, AisMode=None, AisPriority=None, AisUnicastMac=None, AutoDmAllDestination=None, AutoDmDestination=None, AutoDmIteration=None, AutoDmTimeout=None, AutoDmTimer=None, AutoLbAllDestination=None, AutoLbDestination=None, AutoLbIteration=None, AutoLbTimeout=None, AutoLbTimer=None, AutoLmIteration=None, AutoLmTimeout=None, AutoLmTimer=None, AutoLtAllDestination=None, AutoLtDestination=None, AutoLtIteration=None, AutoLtTimeout=None, AutoLtTimer=None, CciInterval=None, CcmLmmTxFcf=None, CcmLmmTxFcfStep=None, CcmPriority=None, CcmRxFcb=None, CcmRxFcbStep=None, ChassisId=None, ChassisIdLength=None, ChassisIdSubType=None, DataTlvLength=None, DataTlvValue=None, DmMethod=None, DmPriority=None, DmmPriority=None, EnableAisRx=None, EnableAutoDm=None, EnableAutoLb=None, EnableAutoLm=None, EnableAutoLt=None, EnableLckRx=None, EnableLmCounterUpdate=None, EnableTstRx=None, Enabled=None, InterRemoteMepRxIncrementStep=None, InterRemoteMepTxIncrementStep=None, LbmPriority=None, LckEnableUnicastMac=None, LckInterval=None, LckMode=None, LckPriority=None, LckSupportAisGeneration=None, LckUnicastMac=None, LmAllRemoteMeps=None, LmDestinationMacAddress=None, LmMethod=None, LmmPriority=None, LmrPriority=None, LmrRxFcf=None, LmrRxFcfStep=None, LtmPriority=None, MacAddress=None, ManagementAddress=None, ManagementAddressDomain=None, ManagementAddressDomainLength=None, ManagementAddressLength=None, MdLevel=None, MegId=None, MegIdFormat=None, MepId=None, MipId=None, MpType=None, OrganizationSpecificTlvLength=None, OrganizationSpecificTlvValue=None, OverrideVlanPriority=None, Rdi=None, ShortMaName=None, ShortMaNameFormat=None, TstEnableUnicastMac=None, TstIncrPacketLength=None, TstIncrPacketLengthStep=None, TstInitialPatternValue=None, TstInterval=None, TstMode=None, TstOverwriteSequenceNumber=None, TstPacketLength=None, TstPatternType=None, TstPriority=None, TstSequenceNumber=None, TstTestType=None, TstUnicastMac=None, Ttl=None, Vlan=None):
		"""Adds a new mp node on the server and retrieves it in this instance.

		Args:
			AddCcmCustomTlvs (bool): If true, adds a custom CCM TLV to bridge messages.
			AddDataTlv (bool): If true, adds a data TLV to bridge messages.
			AddInterfaceStatusTlv (bool): If true, adds an interface status TLV to bridge messages.
			AddLbmCustomTlvs (bool): If true, adds a custom loopback message TLV to bridge messages.
			AddLbrCustomTlvs (bool): If true, adds a custom loopback response message TLV to bridge messages.
			AddLmmCustomTlvs (bool): NOT DEFINED
			AddLmrCustomTlvs (bool): NOT DEFINED
			AddLtmCustomTlvs (bool): If true, adds a custom link trace message TLV to bridge messages.
			AddLtrCustomTlvs (bool): If true, adds a custom link trace message TLV to bridge messages.
			AddOrganizationSpecificTlv (bool): If true, adds a custom organization specific message TLV to bridge messages.
			AddPortStatusTlv (bool): If true, adds a custom port statust message TLV to bridge messages.
			AddSenderIdTlv (bool): If true, adds a custom sender ID message TLV to bridge messages.
			AisEnableUnicastMac (bool): NOT DEFINED
			AisInterval (str(oneSec|oneMin)): NOT DEFINED
			AisMode (str(auto|start|stop)): NOT DEFINED
			AisPriority (number): NOT DEFINED
			AisUnicastMac (str): NOT DEFINED
			AutoDmAllDestination (bool): If true, enables the automatic sending of DM Messages.
			AutoDmDestination (str): The sent MAC address for the DM, if autoDmAllDestination is set to true.
			AutoDmIteration (number): The count for how many times DMMs will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoDmTimeout (number): The timeout period in seconds to wait for a response to DMMs. This value should be less than the Auto LB Timer. Default is 30. Min: 1 Max: 65535
			AutoDmTimer (number): The time period in seconds between DMMs. Default is 60. Min: 1 Max: 65535
			AutoLbAllDestination (bool): If true, enables the automatic sending of Loopback Messages.
			AutoLbDestination (str): Sets the loopback destination MAC address.
			AutoLbIteration (number): The count for how many times LBM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoLbTimeout (number): The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535
			AutoLbTimer (number): The time period in seconds between LBMs. Default is 60. Min: 1 Max: 65535
			AutoLmIteration (number): NOT DEFINED
			AutoLmTimeout (number): NOT DEFINED
			AutoLmTimer (number): NOT DEFINED
			AutoLtAllDestination (bool): If true, enables the automatic sending to Link Trace Messages.
			AutoLtDestination (str): Sets the link trance destination MAC address.
			AutoLtIteration (number): The count for how many times LTM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoLtTimeout (number): The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535
			AutoLtTimer (number): The time period in seconds between LTMs. Default is 60. Min: 1 Max: 65535
			CciInterval (str(3.33msec|10msec|100msec|1sec|10sec|1min|10min)): Sets the Continuity Check Interval (CCI).
			CcmLmmTxFcf (number): NOT DEFINED
			CcmLmmTxFcfStep (number): NOT DEFINED
			CcmPriority (number): Sets the priority for Continuity Check Messages. The default is 0. Min: 0 Max: 7
			CcmRxFcb (number): NOT DEFINED
			CcmRxFcbStep (number): NOT DEFINED
			ChassisId (str): Sets the chassis identification. Default is 00 00 00 00 00 00. This will take Hex value as input (0-255 byte).
			ChassisIdLength (number): Sets the length of the Chassis ID field. Default is 6. Min: 0 Max: 255.
			ChassisIdSubType (str(chassisComponent|interfaceAlias|portComponent|macAddress|networkAddress|interfaceName|locallyAssigned)): Sets the chassis identifier sub-type for the optional TLV messages. Options are:
			DataTlvLength (number): Sets the length of the Data TLV field. Default is 4. Min: 0 Max: 1500.
			DataTlvValue (str): This attribute will take Hex value of data. This data TLV will be added both for periodic LBM and requested LBM transmit. Default is 44 61 74 61.
			DmMethod (str(twoWay|oneWay)): The type of Delay Measurment support.
			DmPriority (number): Sets the priority for DM Messages. This priority will be used only for periodic DMMs one-way or two-way (for both type of DM Methodfor each MIP). The default is 0.
			DmmPriority (number): Sets the priority for DM Messages. This priority will be used only for periodic DMMs. The default is 0. Min: 0 Max: 7
			EnableAisRx (bool): NOT DEFINED
			EnableAutoDm (bool): If true, enables the automatic sending of DM Messages.
			EnableAutoLb (bool): If true, enables the automatic sending of Loopback messages.
			EnableAutoLm (bool): NOT DEFINED
			EnableAutoLt (bool): If true, enables the automatic sending of Link Trace messages.
			EnableLckRx (bool): NOT DEFINED
			EnableLmCounterUpdate (bool): NOT DEFINED
			EnableTstRx (bool): NOT DEFINED
			Enabled (bool): If true, the MP is enabled.
			InterRemoteMepRxIncrementStep (number): NOT DEFINED
			InterRemoteMepTxIncrementStep (number): NOT DEFINED
			LbmPriority (number): Sets the priority for Loopback Messages. This priority will be used only for periodic LBMs. The default is 0. Min: 0 Max: 7
			LckEnableUnicastMac (bool): NOT DEFINED
			LckInterval (str(oneSec|oneMin)): NOT DEFINED
			LckMode (str(auto|start|stop)): NOT DEFINED
			LckPriority (number): NOT DEFINED
			LckSupportAisGeneration (bool): NOT DEFINED
			LckUnicastMac (str): NOT DEFINED
			LmAllRemoteMeps (bool): NOT DEFINED
			LmDestinationMacAddress (str): NOT DEFINED
			LmMethod (str(singleEnded|dualEnded)): NOT DEFINED
			LmmPriority (number): NOT DEFINED
			LmrPriority (number): NOT DEFINED
			LmrRxFcf (number): NOT DEFINED
			LmrRxFcfStep (number): NOT DEFINED
			LtmPriority (number): Sets the priority for Link Trace Messages. This priority will be used only for periodic LTMs. The default is 0. Min: 0 Max: 7
			MacAddress (str): The MAC address of the MP.
			ManagementAddress (str): Sets the MP management address. Input type is HEX (0-255 byte). Default is 01 02 03 03 04 05.
			ManagementAddressDomain (str): Sets the MP management address domain. This will take HEX input (0-255 byte). Default is 4d 61 6e 61 67 65 6d 65 6e 74 20 41 64 64 72 20 44 6f 6d 61 69 6e (Management Addr Domain).
			ManagementAddressDomainLength (number): Sets the length of the Management address domain field. Default is 22. Min: 0 Max: 255.
			ManagementAddressLength (number): Sets the length of the Management address field. Default is 6. Min: 0 Max: 255.
			MdLevel (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=mdLevel)): The MD level of the MP. The MD level must be previously configured.
			MegId (str): The MEG identifier of the MP. This is for use with ITU-T Y.1731.
			MegIdFormat (str(iccBasedFormat|primaryVid|characterString|2octetInteger|rfc2685VpnId)): The MEG identifier format.
			MepId (number): The MEP identifier.
			MipId (number): The MIP identifier.
			MpType (str(mip|mep)): Sets the MP type.
			OrganizationSpecificTlvLength (number): Sets the length of the organizational specific TLV field. Default is 4. Min: 4 Max: 1500
			OrganizationSpecificTlvValue (str): Sets the value of the organizational specific TLV field. This attribute will take Hex value. Default is NULL.
			OverrideVlanPriority (bool): If true, overrides the set VLAN priority for this bridge, and uses the advanced settings instead.
			Rdi (str(auto|on|off)): The Remote Defect Identification.
			ShortMaName (str): Sets the Short MA name. The format is determined in shortMaNameFormat. This is used with IEEE 802.1ag.
			ShortMaNameFormat (str(primaryVid|characterString|2octetInteger|rfc2685VpnId)): Sets the Short MA Name format.
			TstEnableUnicastMac (bool): NOT DEFINED
			TstIncrPacketLength (bool): NOT DEFINED
			TstIncrPacketLengthStep (number): NOT DEFINED
			TstInitialPatternValue (number): NOT DEFINED
			TstInterval (number): NOT DEFINED
			TstMode (str(start|stop)): NOT DEFINED
			TstOverwriteSequenceNumber (bool): NOT DEFINED
			TstPacketLength (number): NOT DEFINED
			TstPatternType (str(nullSignalWithoutCrc32|nullSignalWithCrc32|prbs2311WithoutCrc32|prbs2311WithCrc32)): NOT DEFINED
			TstPriority (number): NOT DEFINED
			TstSequenceNumber (number): NOT DEFINED
			TstTestType (str(inService|outOfService)): NOT DEFINED
			TstUnicastMac (str): NOT DEFINED
			Ttl (number): Sets the MP Time-to-live value. Default is 64. Min: 1 Max: 255
			Vlan (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=vlans)): Assigns a VLAN to the MP. The VLAN must be previously configured.

		Returns:
			self: This instance with all currently retrieved mp data using find and the newly added mp data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the mp data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AddCcmCustomTlvs=None, AddDataTlv=None, AddInterfaceStatusTlv=None, AddLbmCustomTlvs=None, AddLbrCustomTlvs=None, AddLmmCustomTlvs=None, AddLmrCustomTlvs=None, AddLtmCustomTlvs=None, AddLtrCustomTlvs=None, AddOrganizationSpecificTlv=None, AddPortStatusTlv=None, AddSenderIdTlv=None, AisEnableUnicastMac=None, AisInterval=None, AisMode=None, AisPriority=None, AisUnicastMac=None, AutoDmAllDestination=None, AutoDmDestination=None, AutoDmIteration=None, AutoDmTimeout=None, AutoDmTimer=None, AutoLbAllDestination=None, AutoLbDestination=None, AutoLbIteration=None, AutoLbTimeout=None, AutoLbTimer=None, AutoLmIteration=None, AutoLmTimeout=None, AutoLmTimer=None, AutoLtAllDestination=None, AutoLtDestination=None, AutoLtIteration=None, AutoLtTimeout=None, AutoLtTimer=None, CciInterval=None, CcmLmmTxFcf=None, CcmLmmTxFcfStep=None, CcmPriority=None, CcmRxFcb=None, CcmRxFcbStep=None, ChassisId=None, ChassisIdLength=None, ChassisIdSubType=None, DataTlvLength=None, DataTlvValue=None, DmMethod=None, DmPriority=None, DmmPriority=None, EnableAisRx=None, EnableAutoDm=None, EnableAutoLb=None, EnableAutoLm=None, EnableAutoLt=None, EnableLckRx=None, EnableLmCounterUpdate=None, EnableTstRx=None, Enabled=None, InterRemoteMepRxIncrementStep=None, InterRemoteMepTxIncrementStep=None, LbmPriority=None, LckEnableUnicastMac=None, LckInterval=None, LckMode=None, LckPriority=None, LckSupportAisGeneration=None, LckUnicastMac=None, LmAllRemoteMeps=None, LmDestinationMacAddress=None, LmMethod=None, LmmPriority=None, LmrPriority=None, LmrRxFcf=None, LmrRxFcfStep=None, LtmPriority=None, MacAddress=None, ManagementAddress=None, ManagementAddressDomain=None, ManagementAddressDomainLength=None, ManagementAddressLength=None, MdLevel=None, MegId=None, MegIdFormat=None, MepId=None, MipId=None, MpType=None, OrganizationSpecificTlvLength=None, OrganizationSpecificTlvValue=None, OverrideVlanPriority=None, Rdi=None, ShortMaName=None, ShortMaNameFormat=None, TstEnableUnicastMac=None, TstIncrPacketLength=None, TstIncrPacketLengthStep=None, TstInitialPatternValue=None, TstInterval=None, TstMode=None, TstOverwriteSequenceNumber=None, TstPacketLength=None, TstPatternType=None, TstPriority=None, TstSequenceNumber=None, TstTestType=None, TstUnicastMac=None, Ttl=None, Vlan=None):
		"""Finds and retrieves mp data from the server.

		All named parameters support regex and can be used to selectively retrieve mp data from the server.
		By default the find method takes no parameters and will retrieve all mp data from the server.

		Args:
			AddCcmCustomTlvs (bool): If true, adds a custom CCM TLV to bridge messages.
			AddDataTlv (bool): If true, adds a data TLV to bridge messages.
			AddInterfaceStatusTlv (bool): If true, adds an interface status TLV to bridge messages.
			AddLbmCustomTlvs (bool): If true, adds a custom loopback message TLV to bridge messages.
			AddLbrCustomTlvs (bool): If true, adds a custom loopback response message TLV to bridge messages.
			AddLmmCustomTlvs (bool): NOT DEFINED
			AddLmrCustomTlvs (bool): NOT DEFINED
			AddLtmCustomTlvs (bool): If true, adds a custom link trace message TLV to bridge messages.
			AddLtrCustomTlvs (bool): If true, adds a custom link trace message TLV to bridge messages.
			AddOrganizationSpecificTlv (bool): If true, adds a custom organization specific message TLV to bridge messages.
			AddPortStatusTlv (bool): If true, adds a custom port statust message TLV to bridge messages.
			AddSenderIdTlv (bool): If true, adds a custom sender ID message TLV to bridge messages.
			AisEnableUnicastMac (bool): NOT DEFINED
			AisInterval (str(oneSec|oneMin)): NOT DEFINED
			AisMode (str(auto|start|stop)): NOT DEFINED
			AisPriority (number): NOT DEFINED
			AisUnicastMac (str): NOT DEFINED
			AutoDmAllDestination (bool): If true, enables the automatic sending of DM Messages.
			AutoDmDestination (str): The sent MAC address for the DM, if autoDmAllDestination is set to true.
			AutoDmIteration (number): The count for how many times DMMs will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoDmTimeout (number): The timeout period in seconds to wait for a response to DMMs. This value should be less than the Auto LB Timer. Default is 30. Min: 1 Max: 65535
			AutoDmTimer (number): The time period in seconds between DMMs. Default is 60. Min: 1 Max: 65535
			AutoLbAllDestination (bool): If true, enables the automatic sending of Loopback Messages.
			AutoLbDestination (str): Sets the loopback destination MAC address.
			AutoLbIteration (number): The count for how many times LBM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoLbTimeout (number): The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535
			AutoLbTimer (number): The time period in seconds between LBMs. Default is 60. Min: 1 Max: 65535
			AutoLmIteration (number): NOT DEFINED
			AutoLmTimeout (number): NOT DEFINED
			AutoLmTimer (number): NOT DEFINED
			AutoLtAllDestination (bool): If true, enables the automatic sending to Link Trace Messages.
			AutoLtDestination (str): Sets the link trance destination MAC address.
			AutoLtIteration (number): The count for how many times LTM will be transmitted. Default is 0 (no limit). Min: 0 Max: 2^32
			AutoLtTimeout (number): The timeout period in seconds to wait for a response to LTMs. This value should be less than the Auto LT Timer. Default is 30. Min: 1 Max: 65535
			AutoLtTimer (number): The time period in seconds between LTMs. Default is 60. Min: 1 Max: 65535
			CciInterval (str(3.33msec|10msec|100msec|1sec|10sec|1min|10min)): Sets the Continuity Check Interval (CCI).
			CcmLmmTxFcf (number): NOT DEFINED
			CcmLmmTxFcfStep (number): NOT DEFINED
			CcmPriority (number): Sets the priority for Continuity Check Messages. The default is 0. Min: 0 Max: 7
			CcmRxFcb (number): NOT DEFINED
			CcmRxFcbStep (number): NOT DEFINED
			ChassisId (str): Sets the chassis identification. Default is 00 00 00 00 00 00. This will take Hex value as input (0-255 byte).
			ChassisIdLength (number): Sets the length of the Chassis ID field. Default is 6. Min: 0 Max: 255.
			ChassisIdSubType (str(chassisComponent|interfaceAlias|portComponent|macAddress|networkAddress|interfaceName|locallyAssigned)): Sets the chassis identifier sub-type for the optional TLV messages. Options are:
			DataTlvLength (number): Sets the length of the Data TLV field. Default is 4. Min: 0 Max: 1500.
			DataTlvValue (str): This attribute will take Hex value of data. This data TLV will be added both for periodic LBM and requested LBM transmit. Default is 44 61 74 61.
			DmMethod (str(twoWay|oneWay)): The type of Delay Measurment support.
			DmPriority (number): Sets the priority for DM Messages. This priority will be used only for periodic DMMs one-way or two-way (for both type of DM Methodfor each MIP). The default is 0.
			DmmPriority (number): Sets the priority for DM Messages. This priority will be used only for periodic DMMs. The default is 0. Min: 0 Max: 7
			EnableAisRx (bool): NOT DEFINED
			EnableAutoDm (bool): If true, enables the automatic sending of DM Messages.
			EnableAutoLb (bool): If true, enables the automatic sending of Loopback messages.
			EnableAutoLm (bool): NOT DEFINED
			EnableAutoLt (bool): If true, enables the automatic sending of Link Trace messages.
			EnableLckRx (bool): NOT DEFINED
			EnableLmCounterUpdate (bool): NOT DEFINED
			EnableTstRx (bool): NOT DEFINED
			Enabled (bool): If true, the MP is enabled.
			InterRemoteMepRxIncrementStep (number): NOT DEFINED
			InterRemoteMepTxIncrementStep (number): NOT DEFINED
			LbmPriority (number): Sets the priority for Loopback Messages. This priority will be used only for periodic LBMs. The default is 0. Min: 0 Max: 7
			LckEnableUnicastMac (bool): NOT DEFINED
			LckInterval (str(oneSec|oneMin)): NOT DEFINED
			LckMode (str(auto|start|stop)): NOT DEFINED
			LckPriority (number): NOT DEFINED
			LckSupportAisGeneration (bool): NOT DEFINED
			LckUnicastMac (str): NOT DEFINED
			LmAllRemoteMeps (bool): NOT DEFINED
			LmDestinationMacAddress (str): NOT DEFINED
			LmMethod (str(singleEnded|dualEnded)): NOT DEFINED
			LmmPriority (number): NOT DEFINED
			LmrPriority (number): NOT DEFINED
			LmrRxFcf (number): NOT DEFINED
			LmrRxFcfStep (number): NOT DEFINED
			LtmPriority (number): Sets the priority for Link Trace Messages. This priority will be used only for periodic LTMs. The default is 0. Min: 0 Max: 7
			MacAddress (str): The MAC address of the MP.
			ManagementAddress (str): Sets the MP management address. Input type is HEX (0-255 byte). Default is 01 02 03 03 04 05.
			ManagementAddressDomain (str): Sets the MP management address domain. This will take HEX input (0-255 byte). Default is 4d 61 6e 61 67 65 6d 65 6e 74 20 41 64 64 72 20 44 6f 6d 61 69 6e (Management Addr Domain).
			ManagementAddressDomainLength (number): Sets the length of the Management address domain field. Default is 22. Min: 0 Max: 255.
			ManagementAddressLength (number): Sets the length of the Management address field. Default is 6. Min: 0 Max: 255.
			MdLevel (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=mdLevel)): The MD level of the MP. The MD level must be previously configured.
			MegId (str): The MEG identifier of the MP. This is for use with ITU-T Y.1731.
			MegIdFormat (str(iccBasedFormat|primaryVid|characterString|2octetInteger|rfc2685VpnId)): The MEG identifier format.
			MepId (number): The MEP identifier.
			MipId (number): The MIP identifier.
			MpType (str(mip|mep)): Sets the MP type.
			OrganizationSpecificTlvLength (number): Sets the length of the organizational specific TLV field. Default is 4. Min: 4 Max: 1500
			OrganizationSpecificTlvValue (str): Sets the value of the organizational specific TLV field. This attribute will take Hex value. Default is NULL.
			OverrideVlanPriority (bool): If true, overrides the set VLAN priority for this bridge, and uses the advanced settings instead.
			Rdi (str(auto|on|off)): The Remote Defect Identification.
			ShortMaName (str): Sets the Short MA name. The format is determined in shortMaNameFormat. This is used with IEEE 802.1ag.
			ShortMaNameFormat (str(primaryVid|characterString|2octetInteger|rfc2685VpnId)): Sets the Short MA Name format.
			TstEnableUnicastMac (bool): NOT DEFINED
			TstIncrPacketLength (bool): NOT DEFINED
			TstIncrPacketLengthStep (number): NOT DEFINED
			TstInitialPatternValue (number): NOT DEFINED
			TstInterval (number): NOT DEFINED
			TstMode (str(start|stop)): NOT DEFINED
			TstOverwriteSequenceNumber (bool): NOT DEFINED
			TstPacketLength (number): NOT DEFINED
			TstPatternType (str(nullSignalWithoutCrc32|nullSignalWithCrc32|prbs2311WithoutCrc32|prbs2311WithCrc32)): NOT DEFINED
			TstPriority (number): NOT DEFINED
			TstSequenceNumber (number): NOT DEFINED
			TstTestType (str(inService|outOfService)): NOT DEFINED
			TstUnicastMac (str): NOT DEFINED
			Ttl (number): Sets the MP Time-to-live value. Default is 64. Min: 1 Max: 255
			Vlan (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=vlans)): Assigns a VLAN to the MP. The VLAN must be previously configured.

		Returns:
			self: This instance with matching mp data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of mp data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the mp data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)




import sys
import os
sys.path[0] = os.path.abspath(sys.path[0] + '\\..\\..\\')

from ixnetwork_restpy.testplatform.testplatform import TestPlatform

# default output is to the sys.stdout
# to output to a log file, use the log_file_name param
# default tracing is 'none' which is no tracing of request and response messages
test_platform = TestPlatform('127.0.0.1', rest_port=11009, log_file_name='test.log')
sessions = test_platform.Sessions.add()

# trace requests
# the next add vport should show a debug message for the request
print('LOG REQUEST ONLY')
test_platform.Trace='request'
sessions.Ixnetwork.Vport.add()

# trace requests and responses
# the next add vport should show debug messages for the request and response
print('LOG REQUEST AND RESPONSES')
test_platform.Trace='request_response'
sessions.Ixnetwork.Vport.add()

# turn off tracing
# the next add vport should not show debug messages for the request and response
print('LOG NOTHING')
test_platform.Trace='none'
sessions.Ixnetwork.Vport.add()



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Fr(Base):
	"""The Fr class encapsulates a user managed fr node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Fr property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'fr'

	def __init__(self, parent):
		super(Fr, self).__init__(parent)

	@property
	def Count(self):
		"""The total number of DLCIs to create for this range.

		Returns:
			number
		"""
		return self._get_attribute('count')
	@Count.setter
	def Count(self, value):
		self._set_attribute('count', value)

	@property
	def Dlci(self):
		"""The Data Link Connection Identifier (DLCI) value.

		Returns:
			number
		"""
		return self._get_attribute('dlci')
	@Dlci.setter
	def Dlci(self, value):
		self._set_attribute('dlci', value)

	@property
	def EnableIncrement(self):
		"""Creates a range of DLCIs for this entry. Each additional DLCI value will be incremented by 1.

		Returns:
			bool
		"""
		return self._get_attribute('enableIncrement')
	@EnableIncrement.setter
	def EnableIncrement(self, value):
		self._set_attribute('enableIncrement', value)

	@property
	def Enabled(self):
		"""Check this box to enable this Frame Relay (FR) DLCI entry.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def TrafficGroupId(self):
		"""The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	def update(self, Count=None, Dlci=None, EnableIncrement=None, Enabled=None, TrafficGroupId=None):
		"""Updates a child instance of fr on the server.

		Args:
			Count (number): The total number of DLCIs to create for this range.
			Dlci (number): The Data Link Connection Identifier (DLCI) value.
			EnableIncrement (bool): Creates a range of DLCIs for this entry. Each additional DLCI value will be incremented by 1.
			Enabled (bool): Check this box to enable this Frame Relay (FR) DLCI entry.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Count=None, Dlci=None, EnableIncrement=None, Enabled=None, TrafficGroupId=None):
		"""Adds a new fr node on the server and retrieves it in this instance.

		Args:
			Count (number): The total number of DLCIs to create for this range.
			Dlci (number): The Data Link Connection Identifier (DLCI) value.
			EnableIncrement (bool): Creates a range of DLCIs for this entry. Each additional DLCI value will be incremented by 1.
			Enabled (bool): Check this box to enable this Frame Relay (FR) DLCI entry.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			self: This instance with all currently retrieved fr data using find and the newly added fr data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the fr data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, Dlci=None, EnableIncrement=None, Enabled=None, TrafficGroupId=None):
		"""Finds and retrieves fr data from the server.

		All named parameters support regex and can be used to selectively retrieve fr data from the server.
		By default the find method takes no parameters and will retrieve all fr data from the server.

		Args:
			Count (number): The total number of DLCIs to create for this range.
			Dlci (number): The Data Link Connection Identifier (DLCI) value.
			EnableIncrement (bool): Creates a range of DLCIs for this entry. Each additional DLCI value will be incremented by 1.
			Enabled (bool): Check this box to enable this Frame Relay (FR) DLCI entry.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			self: This instance with matching fr data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of fr data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the fr data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Band(Base):
	"""The Band class encapsulates a user managed band node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Band property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'band'

	def __init__(self, parent):
		super(Band, self).__init__(parent)

	@property
	def BurstSize(self):
		"""This indicates the length of the packet or byte burst to consider for applying the meter. The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('burstSize')
	@BurstSize.setter
	def BurstSize(self, value):
		self._set_attribute('burstSize', value)

	@property
	def Description(self):
		"""A description of the band.

		Returns:
			str
		"""
		return self._get_attribute('description')
	@Description.setter
	def Description(self, value):
		self._set_attribute('description', value)

	@property
	def Experimenter(self):
		"""The experimenter ID. The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('experimenter')
	@Experimenter.setter
	def Experimenter(self, value):
		self._set_attribute('experimenter', value)

	@property
	def PrecedenceLevel(self):
		"""This indicates the amount by which the drop precedence of the packet should be increased if the band is exceeded. The default value is 0.

		Returns:
			number
		"""
		return self._get_attribute('precedenceLevel')
	@PrecedenceLevel.setter
	def PrecedenceLevel(self, value):
		self._set_attribute('precedenceLevel', value)

	@property
	def Rate(self):
		"""This indicates the rate value above which the corresponding band may apply to packets The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('rate')
	@Rate.setter
	def Rate(self, value):
		self._set_attribute('rate', value)

	@property
	def Type(self):
		"""Select the band type from the list.

		Returns:
			str(drop|dscpRemark|experimenter)
		"""
		return self._get_attribute('type')
	@Type.setter
	def Type(self, value):
		self._set_attribute('type', value)

	def update(self, BurstSize=None, Description=None, Experimenter=None, PrecedenceLevel=None, Rate=None, Type=None):
		"""Updates a child instance of band on the server.

		Args:
			BurstSize (number): This indicates the length of the packet or byte burst to consider for applying the meter. The default value is 1.
			Description (str): A description of the band.
			Experimenter (number): The experimenter ID. The default value is 1.
			PrecedenceLevel (number): This indicates the amount by which the drop precedence of the packet should be increased if the band is exceeded. The default value is 0.
			Rate (number): This indicates the rate value above which the corresponding band may apply to packets The default value is 1.
			Type (str(drop|dscpRemark|experimenter)): Select the band type from the list.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, BurstSize=None, Description=None, Experimenter=None, PrecedenceLevel=None, Rate=None, Type=None):
		"""Adds a new band node on the server and retrieves it in this instance.

		Args:
			BurstSize (number): This indicates the length of the packet or byte burst to consider for applying the meter. The default value is 1.
			Description (str): A description of the band.
			Experimenter (number): The experimenter ID. The default value is 1.
			PrecedenceLevel (number): This indicates the amount by which the drop precedence of the packet should be increased if the band is exceeded. The default value is 0.
			Rate (number): This indicates the rate value above which the corresponding band may apply to packets The default value is 1.
			Type (str(drop|dscpRemark|experimenter)): Select the band type from the list.

		Returns:
			self: This instance with all currently retrieved band data using find and the newly added band data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the band data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, BurstSize=None, Description=None, Experimenter=None, PrecedenceLevel=None, Rate=None, Type=None):
		"""Finds and retrieves band data from the server.

		All named parameters support regex and can be used to selectively retrieve band data from the server.
		By default the find method takes no parameters and will retrieve all band data from the server.

		Args:
			BurstSize (number): This indicates the length of the packet or byte burst to consider for applying the meter. The default value is 1.
			Description (str): A description of the band.
			Experimenter (number): The experimenter ID. The default value is 1.
			PrecedenceLevel (number): This indicates the amount by which the drop precedence of the packet should be increased if the band is exceeded. The default value is 0.
			Rate (number): This indicates the rate value above which the corresponding band may apply to packets The default value is 1.
			Type (str(drop|dscpRemark|experimenter)): Select the band type from the list.

		Returns:
			self: This instance with matching band data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of band data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the band data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
